@@ -4,7 +4,7 @@ ad_page_contract {
     @param orderyby The parameter to order everything in the page by.
     @param owned_by Display packages owned by whom.
     @author Jon Salz (jsalz@arsdigita.com)
-    @cvs-id $Id: index.tcl,v 1.24.8.1 2013/08/29 13:39:09 victorg Exp $
+    @cvs-id $Id: index.tcl,v 1.24.8.4 2013/10/11 11:43:46 gustafn Exp $
 } {
     { orderby "package_key" }
     { owned_by "everyone" }
@@ -19,7 +19,7 @@ set user_id [ad_conn user_id]
 
 # Determine the user's email address.  If its not registered, put in a default.  
 set my_email [db_string email_by_user_id {
-    select email  from parties where party_id = :user_id
+    select email from parties where party_id = :user_id
 } -default "me"]
 
 set dimensional_list {
@@ -70,6 +70,10 @@ template::list::create -name package_list \
             label "Ver."
             orderby "version_name"
         }
+        release_date {
+            label "Released"
+            orderby "release_date"
+        }
         status {
             label "Status"
         }
@@ -85,12 +89,13 @@ template::list::create -name package_list \
 set performance_p [parameter::get -package_id [ad_acs_kernel_id] -parameter PerformanceModeP -default 1] 
 set reload_links_p [ad_decode [ns_set iget [rp_getform] reload_links_p] \
                         "" 0 [ns_set iget [rp_getform] reload_links_p]]
+
 db_multirow -extend {package_url maintained status action_html} packages apm_table {} {
     set package_url [export_vars -base version-view {version_id}]
     set maintained [ad_decode $distribution_uri "" "Locally" "Externally"]
     
-    if { $installed_p eq "t" } {
-		if { $enabled_p eq "t" } {
+    if { $installed_p == "t" } {
+		if { $enabled_p == "t" } {
 		    set status "Enabled"
 		} else {
 		    set status "Disabled"
@@ -103,11 +108,11 @@ db_multirow -extend {package_url maintained status action_html} packages apm_tab
     
     set file_link_list [list]
     lappend file_link_list "<a href=\"version-files?version_id=$version_id\">view files</a>"
-    if { $installed_p eq "t" && $enabled_p eq "t" } {
+    if { $installed_p == "t" && $enabled_p == "t" } {
         if {!$performance_p} {
             lappend file_link_list "<a href=\"package-watch?package_key=$package_key\">watch all files</a>"
         } 
-        if { !$reload_links_p || [string equal [apm_version_load_status $version_id] "needs_reload"]} {
+        if { !$reload_links_p || [apm_version_load_status $version_id] eq "needs_reload"} {
             lappend file_link_list "<a href=\"version-reload?version_id=$version_id\">reload changed</a>"
         } 
     } 
