@@ -4,9 +4,9 @@ ad_page_contract {
 
     @author Peter Marklund
     @creation-date 28 January 2003
-    @cvs-id $Id: version-callback-add-edit.tcl,v 1.8 2012/12/08 18:20:35 gustafn Exp $  
+    @cvs-id $Id: version-callback-add-edit.tcl,v 1.8.2.2 2014/08/30 16:44:42 gustafn Exp $  
 } {
-    version_id:integer,notnull    
+    version_id:naturalnum,notnull    
     {type ""}
 }
 
@@ -65,12 +65,12 @@ ad_form -name callback -cancel_url $return_url -form {
 
 } -validate {
     {proc
-    { [info commands ::${proc} ne ""] }
-    {The specified procedure name does not exist. Is the -procs.tcl file loaded?}
+	{ {info commands ::$proc} ne "" }
+	{The specified procedure name does not exist. Is the -procs.tcl file loaded?}
     }
     {proc
-    { [apm_callback_has_valid_args -type $type -proc_name $proc] }
-    {The callback proc $proc must be defined with ad_proc [ad_decode [apm_arg_names_for_callback_type -type $type] "" "and should take no arguments" "and have the following required switches: [apm_arg_names_for_callback_type -type $type]"]}
+	{ [apm_callback_has_valid_args -type $type -proc_name $proc] }
+	{The callback proc $proc must be defined with ad_proc [ad_decode [apm_arg_names_for_callback_type -type $type] "" "and should take no arguments" "and have the following required switches: [apm_arg_names_for_callback_type -type $type]"]}
     }
 } -on_submit {
     
