@@ -2,10 +2,10 @@ ad_page_contract {
     Adds a dependency to a version of a package. 
     @author Jon Salz (jsalz@arsdigita.com)
     @creation-date 17 April 2000
-    @cvs-id $Id: version-dependency-remove.tcl,v 1.5 2010/10/17 21:06:07 donb Exp $
+    @cvs-id $Id: version-dependency-remove.tcl,v 1.5.4.3 2014/08/05 10:08:54 gustafn Exp $
 } {
-    {version_id:integer}
-    {dependency_id:integer}
+    {version_id:naturalnum,notnull}
+    {dependency_id:naturalnum,notnull}
     dependency_type:notnull
     package_key:notnull
 }
@@ -23,7 +23,7 @@ db_transaction {
 	}
 
 	default {
-	    ad_return complaint 1 "Dependency Entry Error: Depenendencies are either interfaces or requirements."
+	    ad_return_complaint 1 "Dependency Entry Error: Depenendencies are either interfaces or requirements."
 	}
     }
     apm_package_install_spec $version_id
@@ -32,5 +32,5 @@ db_transaction {
 	<blockquote><pre>[ad_quotehtml $errmsg]</pre></blockquote>"
 }
 
-ad_returnredirect "version-dependencies?[export_url_vars version_id]"
+ad_returnredirect "version-dependencies?[export_vars -url {version_id}]"
 
