@@ -5,16 +5,28 @@ ad_page_contract {
     @author Jon Salz (jsalz@arsdigita.com)
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date 9 May 2000
-    @cvs-id $Id: version-edit.tcl,v 1.10 2009/04/13 23:10:27 donb Exp $
+    @cvs-id $Id: version-edit.tcl,v 1.10.8.9 2014/09/03 20:16:15 gustafn Exp $
 } {
-    {version_id:integer}
+    {version_id:naturalnum,notnull}
 }
 
-db_1row apm_all_version_info {}
+db_1row apm_all_version_info {
+    select version_id, package_key, package_uri, pretty_name, version_name,
+      version_uri, auto_mount, summary, description_format, description, release_date,
+      vendor, vendor_uri, enabled_p, installed_p, tagged_p, imported_p,
+      data_model_loaded_p, activation_date, tarball_length, 
+      deactivation_date, distribution_uri, distribution_date, singleton_p,
+      initial_install_p, implements_subsite_p, inherit_templates_p
+    from apm_package_version_info where version_id = :version_id
+}
 
-doc_body_append "[apm_header -form "action=\"version-edit-2\" method=post" [list "version-view?version_id=$version_id" "$pretty_name $version_name"] "Edit a Version"]
+set title "Edit a Version"
+set context [list \
+		 [list "/acs-admin/apm/" "Package Manager"] \
+		 [list "version-view?version_id=$version_id" "$pretty_name $version_name"] \
+		 $title]
 
-"
+set body "<form action='version-edit-2' method='post'>"
 
 # If the version name is incorporated into the version URL (it will almost always be!)
 # then generate some JavaScript to automatically update the version URL when the
@@ -22,24 +34,24 @@ doc_body_append "[apm_header -form "action=\"version-edit-2\" method=post" [list
 
 set version_name_index [string first $version_name $version_uri]
 if { $version_name_index >= 0 } {
-    set version_uri_prefix [string range $version_uri 0 [expr { $version_name_index - 1 }]]
-    set version_uri_suffix [string range $version_uri [expr { $version_name_index + [string length $version_name] }] end]
+    set version_uri_prefix [string range $version_uri 0 $version_name_index-1]
+    set version_uri_suffix [string range $version_uri $version_name_index+[string length $version_name] end]
 
-    doc_body_append "
-<script type=\"text/javascript\">
+    append body [subst {
+<script type="text/javascript">
 function updateVersionURL() {
     var form = document.forms\[0\];
-    form.version_uri.value = '$version_uri_prefix' + form.version_name.value + '$version_uri_suffix';
+    form.version_uri.value = "$version_uri_prefix" + form.version_name.value + "$version_uri_suffix";
 }
 </script>
-"
+}]
     set version_name_on_change "onChange=\"updateVersionURL()\""
 } else {
     set version_name_on_change ""
 }
 
-doc_body_append "
-<script type=\"text/javascript\">
+append body [subst {
+<script type="text/javascript">
 function checkMailto(element) {
     // If it looks like an email address without a mailto: (contains an @ but
     // no colon) then prepend 'mailto:'.
@@ -48,47 +60,47 @@ function checkMailto(element) {
 }
 </script>
 
-[export_form_vars version_id release_date]
+[export_vars -form {version_id release_date}]
 
 <table>
 
 <tr>
-  <th align=right nowrap>Package Key:</th>
+  <th align="right" nowrap>Package Key:</th>
   <td><tt>$package_key</tt></td>
 </tr>
 <tr>
-  <th align=right nowrap>Package URL:</th>
+  <th align="right" nowrap>Package URL:</th>
   <td>$package_uri</td>
 </tr>
 
 <tr>
-  <th align=right nowrap>Package Name:</th>
+  <th align="right" nowrap>Package Name:</th>
   <td>$pretty_name</td>
 </tr>
 
 <tr>
-  <th align=right nowrap>OpenACS Core:</th>
+  <th align="right" nowrap>OpenACS Core:</th>
   <td>[ad_decode $initial_install_p t Yes No]</td>
 </tr>
 
 <tr>
-  <th align=right nowrap>Singleton:</th>
+  <th align="right" nowrap>Singleton:</th>
   <td>[ad_decode $singleton_p t Yes No]</td>
 </tr>
 
 <tr>
-  <th align=right nowrap>Implements Subsite:</th>
+  <th align="right" nowrap>Implements Subsite:</th>
   <td>[ad_decode $implements_subsite_p t Yes No]</td>
 </tr>
 
 <tr>
-  <th align=right nowrap>Inherit Templates:</th>
+  <th align="right" nowrap>Inherit Templates:</th>
   <td>[ad_decode $inherit_templates_p t Yes No]</td>
 </tr>
 
 <tr>
-  <th align=right nowrap>Auto-mount:</th>
-  <td><input name=auto_mount size=30 value=\"$auto_mount\"></td>
+  <th align="right" nowrap>Auto-mount:</th>
+  <td><input name=auto_mount size=30 value="$auto_mount"></td>
 </tr>
 
 <tr>
@@ -99,31 +111,31 @@ edit the information regarding existing version of the package.</td>
 </tr>
 
 <tr>
-  <th align=right nowrap>Version:</th>
-  <td><input name=version_name size=10 value=\"$version_name\" $version_name_on_change>
+  <th align="right" nowrap>Version:</th>
+  <td><input name="version_name" size="10" value="$version_name" $version_name_on_change>
 </td>
 </tr>
 
 <tr>
-  <th align=right nowrap>Version URL:</th>
-  <td><input name=version_uri size=60 value=\"$version_uri\"></td>
+  <th align="right" nowrap>Version URL:</th>
+  <td><input name="version_uri" size="80" value="$version_uri"></td>
+</tr>
+
+<tr valign="top">
+  <th align="right"><br>Summary:</th>
+  <td><textarea name="summary" cols="60" rows="2" required="required" wrap="soft">[ns_quotehtml $summary]</textarea></td>
 </tr>
 
 <tr valign=top>
-  <th align=right><br>Summary:</th>
-  <td><textarea name=summary cols=60 rows=2 wrap=soft>[ns_quotehtml $summary]</textarea></td>
-</tr>
-
-<tr valign=top>
-  <th align=right><br>Description:</th>
-  <td><textarea name=description cols=60 rows=5 wrap=soft>[ns_quotehtml $description]</textarea><br>
-This description is <select name=description_format>
-<option value=text/html [ad_decode $description_format "text/plain" "" "selected"]>HTML-formatted.
-<option value=text/plain [ad_decode $description_format "text/plain" "selected" ""]>plain text.
+  <th align="right"><br>Description:</th>
+  <td><textarea name="description" cols="60" rows="5" wrap="soft">[ns_quotehtml $description]</textarea><br>
+This description is <select name="description_format">
+<option value="text/html" [ad_decode $description_format "text/plain" "" "selected"]>HTML-formatted.
+<option value="text/plain" [ad_decode $description_format "text/plain" "selected" ""]>plain text.
 </select>
 </td>
 </tr>
-"
+}]
 
 # Dynamic package version attributes
 array set all_attributes [apm::package_version::attributes::get_spec]
@@ -131,7 +143,7 @@ array set attributes [apm::package_version::attributes::get \
                           -version_id $version_id \
                           -array attributes]
 foreach attribute_name [array names all_attributes] {
-    array set attribute $all_attributes($attribute_name)
+    set attribute $all_attributes($attribute_name)
 
     if { [info exists attributes($attribute_name)] } {
         # Attribute is already in db
@@ -140,14 +152,16 @@ foreach attribute_name [array names all_attributes] {
         # The attribute is not in the db yet
         set attribute_value [apm::package_version::attributes::default_value $attribute_name]
     }
-
-    doc_body_append "
+    # provide default size
+    if {![dict exists $attribute size]} {
+	dict set attribute size 30
+    }
+    append body [subst {
 <tr>
-  <th align=right nowrap>${attribute(pretty_name)}:</th>
-  <td><input name=\"$attribute_name\" size=\"30\" value=\"$attribute_value\">
-</td>
+  <th align=right nowrap>[dict get $attribute pretty_name]:</th>
+  <td><input name="$attribute_name" size="[dict get $attribute size]" value="$attribute_value"></td>
 </tr>
-"
+    }]
 }
 
 # Build a list of owners. Ensure that there are at least two.
@@ -173,30 +187,30 @@ foreach owner_info $owners {
 	set prompt "Owner #$counter"
     }
 
-    doc_body_append "
+    append body [subst {
 <tr>
   <th align=right nowrap>$prompt:</th>
-  <td><input name=owner_name size=30 value=\"$owner_name\"></td>
+  <td><input name=owner_name size=30 value="$owner_name"></td>
 </tr>
 <tr>
   <th align=right nowrap>$prompt URL:</th>
-  <td><input name=owner_uri size=30 value=\"$owner_uri\" onChange=\"checkMailto(this)\"></td>
+  <td><input name=owner_uri size=30 value="$owner_uri" onChange="checkMailto(this)"></td>
 </tr>
-"
+    }]
 }
 
-doc_body_append "
+append body [subst {
 <tr>
   <th align=right nowrap>Vendor:</th>
-  <td><input name=vendor size=30 value=\"$vendor\"></td>
+  <td><input name=vendor size=30 value="$vendor"></td>
 </tr>
 <tr>
   <th align=right nowrap>Vendor URL:</th>
-  <td><input name=vendor_uri size=60 value=\"$vendor_uri\"></td>
+  <td><input name=vendor_uri size=60 value="$vendor_uri"></td>
 </tr>
-"
+}]
 
-doc_body_append "
+append body [subst {
 <tr>
   <td></td>
   <td>
@@ -208,12 +222,12 @@ Upgrade the local package $pretty_name to this version and supersede older versi
 
 <tr>
   <td colspan=2 align=center><br>
-<input type=submit value=\"Save Information\">
+<input type=submit value="Save Information">
 </td>
 </tr>
 
 </table>
 </form>
-[ad_footer]
-"
+}]
 
+ad_return_template apm
