@@ -5,17 +5,17 @@ ad_page_contract {
     @author tnight@arsdigita.com
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date 12 September 2000
-    @cvs-id $Id: version-parameters.tcl,v 1.8.4.2 2013/08/29 13:39:09 victorg Exp $
+    @cvs-id $Id: version-parameters.tcl,v 1.8.4.6 2014/08/05 10:08:55 gustafn Exp $
 } {
     {orderby "parameter_name"}
-    {version_id:integer}
+    {version_id:naturalnum,notnull}
     {section_name ""}
 }
 
 db_1row apm_package_by_version_id {
     select pretty_name, version_name, package_key
-      from apm_package_version_info 
-     where version_id = :version_id
+    from apm_package_version_info 
+    where version_id = :version_id
 }
 
 
@@ -69,8 +69,8 @@ append sql_clauses " [template::list::orderby_clause -orderby -name parameters_l
 
 db_multirow -extend {actions} parameters parameter_table {} {
     set actions "\[<font size=-1>
-        <a href=parameter-delete?[export_url_vars parameter_id version_id section_name]>delete</a> | 
-        <a href=parameter-edit?[export_url_vars version_id parameter_id]>edit</a></font>\]"
+        <a href=parameter-delete?[export_vars -url {parameter_id version_id section_name}]>delete</a> | 
+        <a href=parameter-edit?[export_vars -url {version_id parameter_id}]>edit</a></font>\]"
 }
 
 
@@ -84,7 +84,7 @@ if { $dimensional_list ne "" } {
 }
 
 # LARS hack
-set sections [lindex [lindex $dimensional_list 0] 3]
+set sections [lindex $dimensional_list 0 3]
 foreach section $sections {
     if {$section_name eq [lindex $section 0]} {
         set section_name [lindex $section 1]
