@@ -4,11 +4,11 @@ ad_page_contract {
     @author Peter Marklund
     @creation-date 2003-09-08
 } {
-    authority_id:integer
+    authority_id:naturalnum,notnull
 }
 
 # Cannot delete local authority
-if { [string equal $authority_id [auth::authority::local]] } {
+if {$authority_id eq [auth::authority::local]} {
     ad_return_error "Cannot delete local authority" "The system requires the local authority to operate."
 }
 
