@@ -4,12 +4,12 @@ ad_page_contract {
 
     @author Peter Marklund
 } {
-    authority_id:integer
+    authority_id:naturalnum,notnull
 }
 
 # Check that the authority has a register implementation
 auth::authority::get -authority_id $authority_id -array authority
-if { [empty_string_p $authority(register_impl_id)] } {
+if { $authority(register_impl_id) eq "" } {
     ad_return_error "No register driver" "The authority $authority(pretty_name) does not have a register driver and cannot register users"
 }
 
