@@ -5,6 +5,6 @@ ad_page_contract {
     @creation-date 27 Jan 2000
 
 } {
-    user_id
+    user_id:naturalnum,notnull
 }
 
