@@ -3,9 +3,9 @@ ad_page_contract {
     @author Gustaf Neumann <neumann@wu-wien.ac.at>
     @creation-date 23 Dez 2008
 
-    @cvs-id $Id: delete-user.tcl,v 1.1 2008/12/23 08:31:46 gustafn Exp $
+    @cvs-id $Id: delete-user.tcl,v 1.1.8.1 2014/08/05 10:08:56 gustafn Exp $
 } {
-  user_id:integer
+  user_id:naturalnum,notnull
   {return_url .}
   {permanent:boolean f}
 }
