@@ -4,10 +4,10 @@ ad_page_contract {
 
     @author Hiro Iwashima <iwashima@mit.edu>
     @creation-date 23 Aug 2000
-    @cvs-id $Id: member-state-change.tcl,v 1.14 2010/11/08 23:09:10 victorg Exp $
+    @cvs-id $Id: member-state-change.tcl,v 1.14.4.2 2014/08/05 10:08:56 gustafn Exp $
 
 } {
-    user_id
+    user_id:naturalnum,notnull
     {member_state "no_change"}
     {email_verified_p "no_change"}
     {return_url ""}
@@ -91,13 +91,13 @@ set subject "$action"
 set message $email_message
 
 if {$return_url eq ""} {
-    set return_url "/acs-admin/users/one?[export_url_vars user_id]"
+    set return_url "/acs-admin/users/one?[export_vars -url {user_id}]"
 } else {
     ad_returnredirect $return_url
     ad_script_abort
 }
 
 set context [list [list "./" "Users"] "$action"]
-set export_vars [export_url_vars email email_from subject message return_url]
+set export_vars [export_vars -url {email email_from subject message return_url}]
 
 ad_return_template
