@@ -3,10 +3,10 @@ ad_page_contract {
 
     TODO: Support to merge more than two accounts at the same time
 
-    @cvs-id $Id: merge-confirm.tcl,v 1.3 2007/01/10 21:22:00 gustafn Exp $
+    @cvs-id $Id: merge-confirm.tcl,v 1.3.10.1 2014/08/05 10:08:56 gustafn Exp $
 } {
-    to_user_id:integer
-    from_user_id:integer
+    to_user_id:naturalnum,notnull
+    from_user_id:naturalnum,notnull
     merge_action
 } -properties {
     context:onevalue
