@@ -1,9 +1,9 @@
 ad_page_contract {
     Let's the admin change a user's password.
 
-    @version $Id: password-update.tcl,v 1.1.2.5 2005/02/03 20:36:58 joel Exp $
+    @version $Id: password-update.tcl,v 1.3.16.1 2014/08/05 10:08:57 gustafn Exp $
 } {
-    {user_id:integer}
+    {user_id:naturalnum,notnull}
     {return_url ""}
     {password_old ""}
 }
