@@ -3,7 +3,7 @@ ad_library {
     
     @creation-date 2003-09-05
     @author Lars Pind (lars@collaboraid.biz)
-    @cvs-id $Id: sync-procs.tcl,v 1.34.6.1 2013/08/25 20:00:12 gustafn Exp $
+    @cvs-id $Id: sync-procs.tcl,v 1.34.6.4 2014/08/05 09:58:02 gustafn Exp $
 }
 
 namespace eval auth {}
@@ -511,7 +511,7 @@ ad_proc -public auth::sync::purge_jobs {
 } {
     Purge jobs that are older than KeepBatchLogDays days.
 } {
-    if { ![exists_and_not_null num_days] } {
+    if { $num_days eq "" } {
         set num_days [parameter::get_from_package_key \
                           -parameter KeepBatchLogDays \
                           -package_key "acs-authentication" \
@@ -723,7 +723,7 @@ ad_proc -private auth::sync::get_doc::http::GetDocument {
     
     array set param $parameters
     
-    if { ($param(SnapshotURL) ne "" && [string equal [clock format [clock seconds] -format "%d"] "01"]) || \
+    if { ($param(SnapshotURL) ne "" && [clock format [clock seconds] -format "%d"] eq "01") || \
              $param(IncrementalURL) eq "" } {
 
         # On the first day of the month, we get a snapshot
@@ -738,7 +738,8 @@ ad_proc -private auth::sync::get_doc::http::GetDocument {
         error "You must specify at least one URL to get."
     }
 
-    set result(document) [util_httpget $url]
+    set dict [util::http::get -url $url]
+    set result(document) [dict get $dict page]
 
     set result(doc_status) "ok"
 
@@ -800,7 +801,7 @@ ad_proc -private auth::sync::get_doc::file::GetDocument {
     
     array set param $parameters
     
-    if { ($param(SnapshotPath) ne "" && [string equal [clock format [clock seconds] -format "%d"] "01"]) || \
+    if { ($param(SnapshotPath) ne "" && [clock format [clock seconds] -format "%d"] eq "01") || \
              $param(IncrementalPath) eq "" } {
 
         # On the first day of the month, we get a snapshot
