@@ -1,7 +1,7 @@
 ad_page_contract {
-  @cvs-id $Id: component.tcl,v 1.3 2003/09/10 08:54:31 lars Exp $
+  @cvs-id $Id: component.tcl,v 1.3.22.2 2014/08/25 08:17:04 gustafn Exp $
 } {
-  component_id:nohtml
+  component_id:notnull
   package_key:nohtml
 } -properties {
   title:onevalue
@@ -16,11 +16,10 @@ set context [list $title]
 
 set component_bodys {}
 foreach component [nsv_get aa_test components] {
-  if {$component_id == [lindex $component 0] &&
-      $package_key == [lindex $component 1]} {
-    set component_desc     [lindex $component 2]
-    set component_file     [lindex $component 3]
-    set component_body    [lindex $component 4]
+  if {$component_id eq [lindex $component 0] && $package_key eq [lindex $component 1]} {
+    set component_desc [lindex $component 2]
+    set component_file [lindex $component 3]
+    set component_body [lindex $component 4]
   }
 }
 
