@@ -19,7 +19,7 @@ set tested_proc_names [list]
 foreach testcase [nsv_get aa_test cases] {
     set testcase_package_key [lindex $testcase 3]
 
-    if { [string equal $testcase_package_key $package_key] } {
+    if {$testcase_package_key eq $package_key} {
 	set tested_procs [lindex $testcase 10]
 	if { [llength $tested_procs] > 0 } {
 	    set tested_proc_names [concat $tested_proc_names $tested_procs] 
@@ -29,7 +29,7 @@ foreach testcase [nsv_get aa_test cases] {
 
 set uncovered_procs [list]
 foreach proc_name $all_proc_names {
-    if { [lsearch -exact $tested_proc_names $proc_name] == -1 } {
+    if {$proc_name ni $tested_proc_names} {
 	lappend uncovered_procs $proc_name
     }
 }
