@@ -1,17 +1,17 @@
 ad_page_contract {
-    @cvs-id $Id: rerun.tcl,v 1.3 2004/02/16 16:47:28 joela Exp $
+    @cvs-id $Id: rerun.tcl,v 1.4.10.2 2014/08/25 08:17:04 gustafn Exp $
 } {
     {package_key ""}
     {category:aa_test_category ""}
     {view_by:aa_test_view_by "package"}
-    {testcase_id:nohtml ""}
-    {quiet "0"}
-    {stress "0"}
-    {security_risk "0"}
+    {testcase_id ""}
+    {quiet:boolean "0"}
+    {stress:boolean "0"}
+    {security_risk:boolean "0"}
 } -properties {
 }
 
-if {$testcase_id == ""} {
+if {$testcase_id eq ""} {
   if {$quiet} {
     aa_runseries -stress $stress -security_risk $security_risk -quiet $package_key $category
   } else {
