@@ -29,19 +29,19 @@ proc empty_string_p { query_string } {
 }
 
 proc acs_root_dir {} {
-    return [nsv_get acs_properties root_directory]
+    return $::acs::rootdir
 }
 
 proc acs_package_root_dir { package } {
-    return "[file join [acs_root_dir] packages $package]"
+    return [file join $::acs::rootdir packages $package]
 }
 
 proc ad_make_relative_path { path } {
-    set root_length [string length [acs_root_dir]]
-    if { ![string compare [acs_root_dir] [string range $path 0 [expr { $root_length - 1 }]]] } {
-	return [string range $path [expr { $root_length + 1 }] [string length $path]]
+    set root_length [string length $::acs::rootdir]
+    if { $::acs::rootdir eq [string range $path 0 $root_length-1] } {
+	return [string range $path $root_length+1 [string length $path]]
     }
-    error "$path is not under the path root ([acs_root_dir])"
+    error "$path is not under the path root ($::acs::rootdir)"
 }
 
 proc ad_get_tcl_call_stack { { level -2 }} {
@@ -86,7 +86,7 @@ proc ad_parse_documentation_string { doc_string elements_var } {
 }
 
 proc ad_proc_valid_switch_p {str} {
-  return [expr [string equal "-" [string index $str 0]] && ![number_p $str]]
+  return [expr {[string index $str 0] eq "-" && ![number_p $str]}]
 }
 
 proc ad_proc args {
@@ -254,7 +254,7 @@ proc ad_proc args {
         }
     }
 
-    set arg_list [lindex $args [expr { $i + 1 }]]
+    set arg_list [lindex $args $i+1]
     if { $n_args_remaining == 3 } {
         # No doc string provided.
         array set doc_elements [list]
@@ -294,6 +294,7 @@ proc ad_proc args {
     if { [llength $arg_list] > 0 } {
         set first_arg [lindex $arg_list 0]
         if { [llength $first_arg] == 0 || [llength $first_arg] > 2 } {
+	    ns_log Warning "Convert old (deprecated) style proc: $proc_name"
             set new_arg_list [list]
             foreach { switch default_value } $first_arg {
                 lappend new_arg_list [list $switch $default_value]
@@ -305,9 +306,9 @@ proc ad_proc args {
     set effective_arg_list $arg_list
 
     set last_arg [lindex $effective_arg_list end]
-    if { [llength $last_arg] == 1 && [string equal [lindex $last_arg 0] "args"] } {
+    if { [llength $last_arg] == 1 && [lindex $last_arg 0] eq "args" } {
         set varargs_p 1
-        set effective_arg_list [lrange $effective_arg_list 0 [expr { [llength $effective_arg_list] - 2 }]]
+        set effective_arg_list [lrange $effective_arg_list 0 [llength $effective_arg_list]-2]
     }
 
     set check_code ""
@@ -347,7 +348,7 @@ proc ad_proc args {
             set arg [string range $arg 1 end]
             lappend switches $arg
 
-            if { [lsearch $arg_flags "boolean"] >= 0 } {
+            if {"boolean" in $arg_flags} {
                 set default_values(${arg}_p) 0
 		append switch_code "            -$arg - -$arg=1 - -$arg=t - -$arg=true {
                 ::uplevel ::set ${arg}_p 1
@@ -365,7 +366,7 @@ proc ad_proc args {
 		append switch_code "            }\n"
             }
 
-            if { [lsearch $arg_flags "required"] >= 0 } {
+            if {"required" in $arg_flags} {
                 append check_code "    ::if { !\[::uplevel ::info exists $arg\] } {
         ::return -code error \"Required switch -$arg not provided\"
     }
@@ -400,11 +401,10 @@ proc ad_proc args {
         set doc_elements($element) [array get $element]
     }
     
-    set root_dir [nsv_get acs_properties root_directory]
     set script [info script]
-    set root_length [string length $root_dir]
-    if { ![string compare $root_dir [string range $script 0 [expr { $root_length - 1 }]]] } {
-        set script [string range $script [expr { $root_length + 1 }] end]
+    set root_length [string length $::acs::rootdir]
+    if { $::acs::rootdir eq [string range $script 0 $root_length-1] } {
+        set script [string range $script $root_length+1 end]
     }
     
     set doc_elements(script) $script
@@ -416,8 +416,9 @@ proc ad_proc args {
 
     # Backward compatibility: set proc_doc and proc_source_file
     nsv_set proc_doc $proc_name [lindex $doc_elements(main) 0]
-    if { [nsv_exists proc_source_file $proc_name] \
-	    && [nsv_get proc_source_file $proc_name] ne [info script]  } {
+    if { [nsv_exists proc_source_file $proc_name] 
+	 && [nsv_get proc_source_file $proc_name] ne [info script]  
+     } {
         ns_log Warning "Multiple definition of $proc_name in [nsv_get proc_source_file $proc_name] and [info script]"
     }
     nsv_set proc_source_file $proc_name [info script]
@@ -512,15 +513,6 @@ $switch_code
     }
 }
 
-ad_proc -public -deprecated proc_doc { args } {
-
-    A synonym for <code>ad_proc</code> (to support legacy code).
-
-    @see ad_proc
-} {
-    eval ad_proc $args
-}
-
 ad_proc -public ad_proc {
     -public:boolean
     -private:boolean
@@ -684,7 +676,7 @@ ad_proc -public ad_arg_parser { allowed_args argv } {
 } {
     if {[lindex $allowed_args end] eq "args"} {
 	set varargs_p 1
-	set allowed_args [lrange $allowed_args 0 [expr { [llength $allowed_args] - 2 }]]
+	set allowed_args [lrange $allowed_args 0 [llength $allowed_args]-2]
     } else {
 	set varargs_p 0
     }
@@ -774,7 +766,7 @@ ad_proc -public callback {
            list of returns still returned.  If not given an error simply is passed
            further on.
 
-    @params args pass the set of arguments on to each callback
+    @param args pass the set of arguments on to each callback
 
     @return list of the returns from each callback that does a normal (non-empty) return
 
@@ -790,7 +782,7 @@ ad_proc -public callback {
     if {[info commands ::callback::${callback}::contract] eq ""} {
         error "Undefined callback $callback"
     }
-    eval ::callback::${callback}::contract $args
+    ::callback::${callback}::contract {*}$args
 
     set returns {}
 
@@ -827,7 +819,7 @@ ad_proc -public callback {
         }
     }
 
-    if {![string equal $impl *] && ![info exists c] && !$catch_p} {
+    if {$impl ne "*" && ![info exists c] && !$catch_p} {
         error "callback $callback implementation $impl does not exist"
     }
 
@@ -853,7 +845,7 @@ ad_library {
 
     @creation-date 7 Jun 2000
     @author Jon Salz (jsalz@mit.edu)
-    @cvs-id $Id: 00-proc-procs.tcl,v 1.41.2.3 2013/08/25 19:54:34 gustafn Exp $
+    @cvs-id $Id: 00-proc-procs.tcl,v 1.41.2.15 2014/09/08 07:01:46 gustafn Exp $
 }
 
 ad_proc -public empty_string_p {query_string} {
@@ -910,7 +902,7 @@ ad_proc -public ad_call_method {
     @param object_id the target, it is the first arg to the method
     @param args the remaining arguments
 } {
-    return [ad_apply ${method_name}__[util_memoize "acs_object_type $object_id"] [concat $object_id $args]]
+    return [ad_apply ${method_name}__[util_memoize [list acs_object_type $object_id]] [concat $object_id $args]]
 }
 
 ad_proc -public ad_dispatch {
@@ -938,8 +930,8 @@ ad_proc -public ad_assert_arg_value_in_list {
     For use at the beginning of the body of a procedure to
     check that an argument has one of a number of allowed values.
 
-    @arg_name The name of the argument to check
-    @allowed_values_list The list of values that are permissible for the argument
+    @param arg_name The name of the argument to check
+    @param allowed_values_list The list of values that are permissible for the argument
 
     @return Returns 1 if the argument has a valid value, throws an informative
                     error otherwise.
@@ -948,7 +940,7 @@ ad_proc -public ad_assert_arg_value_in_list {
 } {
     upvar $arg_name arg_value
 
-    if { [lsearch -exact $allowed_values_list $arg_value] == -1 } {
+    if {$arg_value ni $allowed_values_list} {
         error "argument $arg_name has value $arg_value but must be in ([join $allowed_values_list ", "])"
     }
 
