@@ -4,7 +4,7 @@
 -- Copyright (C) 1999-2000 ArsDigita Corporation
 -- Author: Karl Goldstein (karlg@arsdigita.com)
 
--- $Id: content-create.sql,v 1.29 2011/04/11 01:08:27 donb Exp $
+-- $Id: content-create.sql,v 1.29.4.1 2013/08/28 22:47:12 michaels Exp $
 
 -- This is free software distributed under the terms of the GNU Public
 -- License.  Full text of the license is available from the GNU Project:
@@ -766,7 +766,8 @@ begin
         ) select :old.filename, i.storage_area_key
             from cr_items i
            where i.item_id = :old.item_id
-             and i.storage_type = 'file';
+             and i.storage_type = 'file'
+             and r.content is not null;
 
 end cr_cleanup_cr_files_del_trg;
 /
