@@ -1,4 +1,3 @@
-
 create or replace package content_item
 as
 
@@ -84,7 +83,8 @@ function new (
   data	        in cr_revisions.content%TYPE default null,
   relation_tag  in cr_child_rels.relation_tag%TYPE default null,
   is_live       in char default 'f',
-  storage_type  in cr_items.storage_type%TYPE default 'lob'
+  storage_type  in cr_items.storage_type%TYPE default 'lob',
+  security_inherit_p in acs_objects.security_inherit_p%TYPE default 't'
 ) return cr_items.item_id%TYPE;
 
 
@@ -516,6 +516,7 @@ end content_item;
 /
 show errors
 
+	
 create or replace package content_folder
 as
 
@@ -541,7 +542,9 @@ function new (
   folder_id	in cr_folders.folder_id%TYPE default null,
   creation_date	in acs_objects.creation_date%TYPE default sysdate,
   creation_user	in acs_objects.creation_user%TYPE default null,
-  creation_ip	in acs_objects.creation_ip%TYPE default null
+  creation_ip	in acs_objects.creation_ip%TYPE default null,
+  security_inherit_p in acs_objects.security_inherit_p%TYPE default 't',
+  package_id	in cr_folders.package_id%TYPE default null
 ) return cr_folders.folder_id%TYPE;
 
 procedure del (
@@ -728,6 +731,8 @@ end content_folder;
 /
 show errors
 
+
+
 create or replace package body content_item
 as
 
@@ -791,7 +796,8 @@ function new (
   data	        in cr_revisions.content%TYPE default null,
   relation_tag  in cr_child_rels.relation_tag%TYPE default null,
   is_live       in char default 'f',
-  storage_type  in cr_items.storage_type%TYPE default 'lob'
+  storage_type  in cr_items.storage_type%TYPE default 'lob',
+  security_inherit_p in acs_objects.security_inherit_p%TYPE default 't'
 ) return cr_items.item_id%TYPE
 is
   v_parent_id      cr_items.parent_id%TYPE;
@@ -887,7 +893,8 @@ begin
       context_id        => v_context_id,
       creation_date	=> content_item.new.creation_date, 
       creation_user	=> content_item.new.creation_user, 
-      creation_ip	=> content_item.new.creation_ip 
+      creation_ip	=> content_item.new.creation_ip,
+      security_inherit_p => content_item.new.security_inherit_p
   );
 
   -- Turn off security inheritance if there is no security context
@@ -2434,6 +2441,8 @@ end content_item;
 /
 show errors
 
+
+
 create or replace package body content_folder
 as
 
@@ -2446,7 +2455,9 @@ function new (
   folder_id	in cr_folders.folder_id%TYPE default null,
   creation_date	in acs_objects.creation_date%TYPE default sysdate,
   creation_user	in acs_objects.creation_user%TYPE default null,
-  creation_ip	in acs_objects.creation_ip%TYPE default null
+  creation_ip	in acs_objects.creation_ip%TYPE default null,
+  security_inherit_p in acs_objects.security_inherit_p%TYPE default 't',
+  package_id	in cr_folders.package_id%TYPE default null
 ) return cr_folders.folder_id%TYPE is
   v_folder_id	cr_folders.folder_id%TYPE;
   v_context_id	acs_objects.context_id%TYPE;
@@ -2476,13 +2487,14 @@ begin
         creation_date => creation_date, 
         creation_user => creation_user, 
         creation_ip   => creation_ip, 
-        parent_id     => parent_id 
+        parent_id     => parent_id,
+	security_inherit_p => security_inherit_p
     );
 
     insert into cr_folders (
-      folder_id, label, description
+      folder_id, label, description, package_id
     ) values (
-      v_folder_id, label, description
+      v_folder_id, label, description, package_id
     );
 
     -- inherit the attributes of the parent folder
@@ -2849,14 +2861,15 @@ begin
   open c_tree_cur;
   while v_parent_id <> folder_id loop
     fetch c_tree_cur into v_parent_id;
+
+    if v_parent_id = folder_id then
+        v_sub_folder_p := 't';
+    end if;
+
     exit when c_tree_cur%NOTFOUND;
   end loop;
   close c_tree_cur;
 
-  if v_parent_id ^= 0 then 
-    v_sub_folder_p := 't';
-  end if;
-
   return v_sub_folder_p;
 
 end is_sub_folder;
@@ -3081,4 +3094,13 @@ end is_root;
 end content_folder;
 /
 show errors
+-- 
 
+-- @author Dave Bauer (dave@thedesignexperience.org)
+-- @creation-date 2004-05-02
+-- @cvs-id $Id: upgrade-5.1.5d2-5.1.5d3.sql,v 1.3 2006/12/15 00:01:09 donb Exp $
+--
+
+-- reload packages to get fixed version of content_folder.rename
+
+@@ ../packages-create.sql
