@@ -12,7 +12,7 @@
 --
 -- @creation-date 2000-05-18
 --
--- @cvs-id $Id: acs-metadata-create.sql,v 1.41 2011/07/31 23:11:46 donb Exp $
+-- @cvs-id $Id: acs-metadata-create.sql,v 1.41.2.1 2014/07/03 11:57:13 victorg Exp $
 
 -- ******************************************************************
 -- * KNOWLEDGE LEVEL
@@ -462,7 +462,7 @@ create table acs_attributes (
 	sort_order	integer not null,
 	datatype	varchar(50) not null
 			constraint acs_attributes_datatype_fk
-			references acs_datatypes (datatype),
+			references acs_datatypes (datatype) on update cascade,
 	default_value	text,
 	min_n_values	integer default 1 not null
 			constraint acs_attributes_min_n_values_ck
