@@ -10,7 +10,7 @@ ad_library {
     @creation-date 28 September 2000
     @author Henry Minsky (hqm@mit.edu)
     @author Lars Pind (lars@pinds.com)
-    @cvs-id $Id: locale-procs.tcl,v 1.38.2.1 2013/08/27 12:20:35 gustafn Exp $
+    @cvs-id $Id: locale-procs.tcl,v 1.38.2.2 2013/10/02 09:10:22 gustafn Exp $
 }
 
 namespace eval lang::system {}
@@ -42,7 +42,7 @@ ad_proc -public lang::system::site_wide_locale {
 
     # Check validity of parameter setting
     set valid_locales [lang::system::get_locales]
-    if { [lsearch -exact $valid_locales $parameter_locale] == -1 } {
+    if {$parameter_locale ni $valid_locales} {
         ns_log Error "The parameter setting acs-lang.SiteWideLocale=\"$parameter_locale\" is invalid. Valid locales are: \"$valid_locales\". Defaulting to en_US locale"
         return en_US
     }
@@ -572,7 +572,7 @@ ad_proc -private lang::conn::browser_locale {} {
 
         if { ([info exists region] && $region ne "") } {
             # We have both language and region, e.g. en_US
-            if { [lsearch -exact $system_locales $locale] != -1 } {
+            if {$locale in $system_locales} {
                 # The locale was found in the system, a perfect match           
                 set perfect_match $locale
                 break
