@@ -34,7 +34,7 @@ ad_proc -private lang::test::test_package_key {} {
 ad_proc -private lang::test::setup_test_package {} {
     set package_key [test_package_key]
     set package_name "acs-lang temporary test package"
-    set package_dir [file join [acs_root_dir] packages $package_key]
+    set package_dir [file join $::acs::rootdir packages $package_key]
     file mkdir $package_dir
 
     set info_file_path "${package_dir}/${package_key}.info"
@@ -61,7 +61,7 @@ ad_proc -private lang::test::setup_test_package {} {
         -enable \
         [apm_package_info_file_path $package_key]
     aa_true "Package install: package enabled" \
-        [expr [lsearch -exact [apm_enabled_packages] $package_key] != -1]
+        [expr {$package_key in [apm_enabled_packages]}]
 }
 
 ad_proc -private lang::test::teardown_test_package {} {
@@ -114,12 +114,12 @@ ad_proc -private lang::test::check_import_result {
         aa_equals "Import check: $message_key - lang_messages.conflict_p" $message_actual(conflict_p) $expect_property(conflict_p)
         aa_equals "Import check: $message_key - lang_messages.upgrade_status" \
             $message_actual(upgrade_status) $expect_property(upgrade_status)
-        if { [string equal $expect_property(sync_time) "not_null"] } {
+        if {$expect_property(sync_time) eq "not_null"} {
             aa_true "Import check: $message_key - lang_messages.sync_time not null" \
-                [expr ![empty_string_p $message_actual(sync_time)]]
+                [expr {$message_actual(sync_time) ne ""}] 
         } else {
             aa_true "Import check: $message_key - lang_messages.sync_time null" \
-                [expr [empty_string_p $message_actual(sync_time)]]
+                [expr {$message_actual(sync_time) eq ""}]
         }
     }
 }
@@ -350,7 +350,7 @@ ad_proc -private lang::test::execute_upgrade {
             # Message is supposed to exist in DB
             # Is it new or changed?
             if { ![info exists base_messages($message_key)] || \
-                     ![string equal $base_messages($message_key) $db_messages($message_key)] } {
+                     $base_messages($message_key) ne $db_messages($message_key) } {
                 # Added || updated 
                 aa_log "Adding/updating message $message_key"
                 lang::message::register \
@@ -414,7 +414,7 @@ ad_proc -private lang::test::execute_upgrade {
         key08 "accept"
     }
     foreach message_key [array names conflict_resolutions] {
-        if { [string equal $conflict_resolutions($message_key) "accept"] } {
+        if {$conflict_resolutions($message_key) eq "accept"} {
             # Resolution is an accept - just toggle conflict_p flag
             lang::message::edit $package_key $message_key $locale [list conflict_p f]
 
@@ -500,7 +500,7 @@ aa_register_case \
     set expected_new_keys [list Auto_Key key_1_1] 
 
     # Write the test tcl file
-    set tcl_file_id [open "[acs_root_dir]/$tcl_file" w]    
+    set tcl_file_id [open "$::acs::rootdir/$tcl_file" w]    
     set new_key_1 "_"
     set new_text_1 "Auto Key"
     set new_key_2 "key_1"
@@ -551,10 +551,10 @@ aa_register_case \
                                                    $messages_array($new_key_3)]
 
     # Check that there are no tags left in the tcl file
-    set tcl_file_id [open "[acs_root_dir]/$tcl_file" r]
+    set tcl_file_id [open "$::acs::rootdir/$tcl_file" r]
     set updated_tcl_contents [read $tcl_file_id]
     close $tcl_file_id
-    aa_true "tags in tcl file replaced" [expr [llength [lang::util::get_temporary_tags_indices $updated_tcl_contents]] == 0]
+    aa_true "tags in tcl file replaced" [expr {[llength [lang::util::get_temporary_tags_indices $updated_tcl_contents]] == 0}]
 
     # Delete the test message keys
     foreach message_key [concat [array names messages_array] $expected_new_keys] {
@@ -565,8 +565,8 @@ aa_register_case \
     file delete $catalog_file
 
     # Delete the tcl files
-    file delete "[acs_root_dir]/$tcl_file"
-    file delete "[acs_root_dir]/$tcl_backup_file"
+    file delete "$::acs::rootdir/$tcl_file"
+    file delete "$::acs::rootdir/$tcl_backup_file"
 }
 
 aa_register_case \
@@ -581,17 +581,17 @@ aa_register_case \
   set indices_list [lang::util::get_hash_indices $multilingual_string]
   set expected_indices_list [list [list 0 14] [list 21 35]]
 
-  aa_true "there should be two hash entries" [expr [llength $indices_list] == 2]
+  aa_true "there should be two hash entries" [expr {[llength $indices_list] == 2}]
 
   set counter 0
   foreach index_item $indices_list {
       set expected_index_item [lindex $expected_indices_list $counter]
       
       aa_true "checking start and end indices of item $counter" \
-              [expr [string equal [lindex $index_item 0] [lindex $expected_index_item 0]] && \
-              [string equal [lindex $index_item 1] [lindex $expected_index_item 1]]]
+	  [expr {[lindex $index_item 0] eq [lindex $expected_index_item 0]
+		 && [lindex $index_item 1] eq [lindex $expected_index_item 1]}]
 
-      set counter [expr $counter + 1]
+      set counter [expr {$counter + 1}]
   }
 }
 
@@ -861,8 +861,8 @@ aa_register_case \
 
         set timezones [lc_list_all_timezones]
         
-        set desired_user_timezone [lindex [lindex $timezones [randomRange [expr [llength $timezones]-1]]] 0]
-        set desired_system_timezone [lindex [lindex $timezones [randomRange [expr [llength $timezones]-1]]] 0]
+        set desired_user_timezone [lindex [lindex $timezones [randomRange [expr {[llength $timezones]-1}]]] 0]
+        set desired_system_timezone [lindex [lindex $timezones [randomRange [expr {[llength $timezones]-1}]]] 0]
         
         set error_p 0
         with_catch errmsg {
@@ -1063,3 +1063,15 @@ aa_register_case -procs {
             lang::message::unregister $package_key $message_key
         }
 }
+
+aa_register_case lang_messages_correct {
+    This test calls the checks to ensure a message is correct on every message in the system
+} {
+    aa_run_with_teardown -rollback -test_code {
+	db_foreach query "
+	  select message_key, package_key, locale, message from lang_messages" {
+	    aa_false "Message $message_key in package $package_key for locale $locale correct" \
+	      [catch {lang::message::check $locale $package_key $message_key $message}]
+	}
+    }
+}
