@@ -5,7 +5,7 @@ ad_page_contract {
     @author Lars Pind (lars@collaboraid.biz)
 
     @creation-date 2003-08-15
-    @cvs-id $Id: message-delete.tcl,v 1.5 2008/04/18 06:48:43 victorg Exp $
+    @cvs-id $Id: message-delete.tcl,v 1.5.8.1 2013/08/27 12:20:36 gustafn Exp $
 
 } {
     locale
@@ -31,7 +31,7 @@ set context [list [list "package-list?[export_vars { locale }]" $locale_label] \
 set form_export_vars [export_vars -form { locale package_key message_key show {confirm_p 1} }]
 
 
-if { [exists_and_not_null confirm_p] && [template::util::is_true $confirm_p] } {
+if { ([info exists confirm_p] && $confirm_p ne "") && [template::util::is_true $confirm_p] } {
     lang::message::delete \
         -package_key $package_key \
         -message_key $message_key \
