@@ -12,6 +12,6 @@ set context_bar [ad_context_bar]
 # Get user pref setting
 #
 
-set locale [ad_locale user locale]
-set language [ad_locale user language]
-set admin_p [ad_permission_p [ad_conn package_id] admin]
+set locale [lang::user::locale]
+set language [lang::user::language]
+set admin_p [permission::permission_p -object_id [ad_conn package_id] -privilege admin]
