@@ -4,9 +4,9 @@ ad_page_contract {
     @param repository_id 
     @author Jon Griffin (jon@jongriffin.com)
     @creation-date 17 Sept 2001
-    @cvs-id $Id: view-one-reference.tcl,v 1.3 2005/03/01 00:01:22 jeffd Exp $
+    @cvs-id $Id: view-one-reference.tcl,v 1.3.16.1 2014/07/29 11:23:55 gustafn Exp $
 } {
-    repository_id:integer,notnull
+    repository_id:naturalnum,notnull
 } -properties {
     context_bar:onevalue
     package_id:onevalue
