@@ -6,7 +6,7 @@ ad_library {
 
     @author oumi@arsdigita.com
     @creation-date 2001-02-01
-    @cvs-id $Id: application-group-procs.tcl,v 1.15 2009/09/23 21:12:11 donb Exp $
+    @cvs-id $Id: application-group-procs.tcl,v 1.15.6.1 2013/08/27 12:20:36 gustafn Exp $
 
 }
 
@@ -281,8 +281,8 @@ ad_proc -public application_group::closest_ancestor_application_group_site_node
     @author Peter Marklund, Dave Bauer
 } {
     # Make sure we have a url to work with
-    if { [empty_string_p $url] } {
-          if { [empty_string_p $node_id] } {
+    if { $url eq "" } {
+          if { $node_id eq "" } {
               set url "/"
           } else {
               set url [site_node::get_url -node_id $node_id]
