@@ -6,7 +6,7 @@ ad_library {
 
     @author mbryzek@arsdigita.com
     @creation-date Sun Dec 10 16:46:11 2000
-    @cvs-id $Id: relation-procs.tcl,v 1.15 2007/01/10 21:22:06 gustafn Exp $
+    @cvs-id $Id: relation-procs.tcl,v 1.15.10.1 2013/09/06 12:06:49 gustafn Exp $
 
 }
 
@@ -23,7 +23,7 @@ ad_proc -public relation_permission_p {
     @creation-date 12/2000
 
 } {
-    return [ad_permission_p -user_id $user_id $rel_id $privilege]
+    return [permission::permission_p -party_id $user_id -object_id $rel_id -privilege $privilege]
 }
 
 
