@@ -3,9 +3,9 @@ ad_page_contract {
 
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-05-28
-    @cvs-id $Id: application-add.tcl,v 1.11 2011/04/15 10:29:16 emmar Exp $
+    @cvs-id $Id: application-add.tcl,v 1.11.4.1 2014/07/29 11:14:15 gustafn Exp $
 } {
-    node_id:integer,optional
+    node_id:naturalnum,optional
     {return_url "."}
 }
 
