@@ -3,14 +3,14 @@ ad_page_contract {
 
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-06-02
-    @cvs-id $Id: index.tcl,v 1.10 2011/04/15 10:29:16 emmar Exp $
+    @cvs-id $Id: index.tcl,v 1.10.4.1 2013/09/08 08:16:25 gustafn Exp $
 }
 
 set page_title "[_ acs-subsite.Applications]"
 set context [list $page_title]
 
 # Get the subsite node ID
-set subsite_url [site_node_closest_ancestor_package_url]
+set subsite_url [lindex [site_node::get_url_from_object_id -object_id [site_node::closest_ancestor_package -include_self -package_key [subsite::package_keys]]] 0]
 array set subsite_sitenode [site_node::get -url $subsite_url]
 set subsite_node_id $subsite_sitenode(node_id)
 
