@@ -3,9 +3,9 @@ ad_page_contract {
     
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-06-13
-    @cvs-id $Id: permissions-user-add.tcl,v 1.1 2003/09/29 11:53:35 lars Exp $
+    @cvs-id $Id: permissions-user-add.tcl,v 1.1.22.1 2014/08/05 09:49:23 gustafn Exp $
 } {
-    object_id:integer
+    object_id:naturalnum,notnull
 }
 
 set page_title "Add User"
