@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Nov  7 12:14:42 2000
-    @cvs-id $Id: add-2.tcl,v 1.3 2007/01/10 21:22:06 gustafn Exp $
+    @cvs-id $Id: add-2.tcl,v 1.3.10.5 2013/10/10 21:00:46 gustafn Exp $
 
 } {
     object_type:notnull,trim
@@ -39,7 +39,7 @@ if { [attribute::exists_p $object_type $pretty_name] } {
 
 # Right now, we do not support multiple values for attributes
 set max_n_values 1
-if {$required_p eq "t"} {
+if {$required_p == "t"} {
     set min_n_values 1
 } else {
     set min_n_values 0
@@ -57,9 +57,9 @@ db_transaction {
 
 # If we're an enumeration, redirect to start adding possible values.
 if {$datatype eq "enumeration"} {
-    ad_returnredirect enum-add?[ad_export_vars {attribute_id return_url}]
+    ad_returnredirect enum-add?[export_vars {attribute_id return_url}]
 } elseif { $return_url eq "" } {
-    ad_returnredirect add?[ad_export_vars {object_type}]
+    ad_returnredirect add?[export_vars {object_type}]
 } else {
     ad_returnredirect $return_url
 }
