@@ -6,10 +6,10 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Nov  7 12:14:42 2000
-    @cvs-id $Id: enum-add.tcl,v 1.3 2007/01/10 21:22:06 gustafn Exp $
+    @cvs-id $Id: enum-add.tcl,v 1.3.10.5 2014/07/29 11:23:56 gustafn Exp $
 
 } {
-    attribute_id:integer,notnull
+    attribute_id:naturalnum,notnull
     { return_url "" }
 } -properties {
     context:onevalue
@@ -49,8 +49,8 @@ db_1row select_attr_name {
      where a.attribute_id = :attribute_id
 }
 
-set context [list [list one?[export_url_vars attribute_id] "One attribute"] "Add values"]
+set context [list [list one?[export_vars -url {attribute_id}] "One attribute"] "Add values"]
 
-set export_vars [ad_export_vars -form {attribute_id return_url}]
+set export_vars [export_vars -form {attribute_id return_url}]
 
 ad_return_template
