@@ -6,7 +6,7 @@ ad_page_contract {
     @author Oumi Mehrotra (oumi@arsdigita.com)
 
     @creation-date 2001-02-23
-    @cvs-id $Id: change-join-policy-2.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: change-join-policy-2.tcl,v 1.2.10.5 2013/10/10 21:00:46 gustafn Exp $
 } {
     group_type:notnull
     default_join_policy:notnull
@@ -24,7 +24,7 @@ if { ![db_0or1row select_pretty_name {
     return
 }
 
-if {![string equal $dynamic_p t]} {
+if {$dynamic_p != "t" } {
     ad_return_error "Cannot administer group type" "Group type \"$group_type\" can only be administered by programmers"
 }
 
@@ -44,8 +44,8 @@ if {!$group_type_exists_p} {
     }
 }
 
-if {[empty_string_p $return_url]} {
-    set return_url one?[ad_export_vars group_type]
+if {$return_url eq ""} {
+    set return_url one?[export_vars group_type]
 }
 
 ad_returnredirect $return_url
\ No newline at end of file
