@@ -6,7 +6,7 @@ ad_page_contract {
     @author Oumi Mehrotra (oumi@arsdigita.com)
 
     @creation-date 2001-02-23
-    @cvs-id $Id: change-join-policy.tcl,v 1.4 2007/01/10 21:22:06 gustafn Exp $
+    @cvs-id $Id: change-join-policy.tcl,v 1.4.10.5 2013/10/10 21:00:46 gustafn Exp $
 } {
     group_type:notnull
     {return_url ""}
@@ -23,7 +23,7 @@ ad_page_contract {
 
 set context [list \
         [list "[ad_conn package_url]admin/group-types/" "Group types"] \
-	[list "one?[ad_export_vars group_type]" "One type"] \
+	[list "one?[export_vars group_type]" "One type"] \
 	"Edit default join policy"]
 
 if { ![db_0or1row select_pretty_name {
@@ -37,7 +37,7 @@ if { ![db_0or1row select_pretty_name {
     return
 }
 
-if {$dynamic_p ne "t" } {
+if {$dynamic_p != "t" } {
     ad_return_error "Cannot administer group type" "Group type \"$group_type\" can only be administered by programmers"
 }
 
