@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Sun Dec 10 16:45:32 2000
-    @cvs-id $Id: rel-type-remove-2.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: rel-type-remove-2.tcl,v 1.2.10.4 2013/09/09 16:44:20 gustafn Exp $
 
 } {
     group_rel_type_id:naturalnum,notnull
@@ -14,17 +14,17 @@ ad_page_contract {
     { operation:trim "No, I want to cancel my request" }
 }
 
-if { [empty_string_p $return_url] } {
+if { $return_url eq "" } {
     # Pull out the group_type now as we may delete the row later
     db_1row select_group_type {
 	select g.group_type
 	from group_type_rels g 
 	where g.group_rel_type_id = :group_rel_type_id
     }
-    set return_url one?[ad_export_vars {group_type}]
+    set return_url one?[export_vars {group_type}]
 }
 
-if { [string eq $operation "Yes, I really want to remove this relationship type"] } {
+if {$operation eq "Yes, I really want to remove this relationship type"} {
     db_transaction {
 	db_dml remove_relation {
 	    delete from group_type_rels where group_rel_type_id = :group_rel_type_id
