@@ -6,9 +6,9 @@ ad_page_contract {
     @author Oumi Mehrotra (oumi@arsdigita.com)
 
     @creation-date 2001-02-23
-    @cvs-id $Id: change-join-policy-2.tcl,v 1.2 2007/01/10 21:22:07 gustafn Exp $
+    @cvs-id $Id: change-join-policy-2.tcl,v 1.2.10.1 2014/07/29 11:23:56 gustafn Exp $
 } {
-    group_id:integer,notnull
+    group_id:naturalnum,notnull
     join_policy:notnull
     {return_url ""}
 } -validate {
