@@ -6,10 +6,10 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Fri Dec  8 14:41:36 2000
-    @cvs-id $Id: delete-2.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: delete-2.tcl,v 1.2.10.5 2014/07/29 11:23:56 gustafn Exp $
 
 } {
-    group_id:integer,notnull
+    group_id:naturalnum,notnull
     { operation "" }
     { return_url "" }
 } -validate {
@@ -20,16 +20,16 @@ ad_page_contract {
     }
 }
 
-if { [string eq $operation "Yes, I really want to delete this group"] } {
+if {$operation eq "Yes, I really want to delete this group"} {
     db_transaction {
 	set group_type [group::delete $group_id]
     }
-    if { [empty_string_p $return_url] && ![empty_string_p $group_type] } {
-	set return_url "../group-types/one?[ad_export_vars group_type]"
+    if { $return_url eq "" && $group_type ne "" } {
+	set return_url "../group-types/one?[export_vars group_type]"
     }
 } else {
-    if { [empty_string_p $return_url] } {
-	set return_url "one?[ad_export_vars group_id]"
+    if { $return_url eq "" } {
+	set return_url "one?[export_vars group_id]"
     }
 }
 
