@@ -7,10 +7,10 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Jan  2 12:10:17 2001
-    @cvs-id $Id: rel-type-add-2.tcl,v 1.4 2010/10/04 21:59:20 victorg Exp $
+    @cvs-id $Id: rel-type-add-2.tcl,v 1.4.4.5 2014/07/29 11:23:56 gustafn Exp $
 
 } {
-    group_id:integer,notnull
+    group_id:naturalnum,notnull
     rel_type:notnull
     { return_url "" }
 } -validate {
@@ -67,10 +67,10 @@ if { [db_string segment_exists_p {
       from dual
 }] } {
     if { $return_url eq "" } {
-	set return_url one?[ad_export_vars group_id]
+	set return_url one?[export_vars group_id]
     }
     ad_returnredirect $return_url 
 } else {
-    ad_returnredirect constraints-create?[ad_export_vars {group_id rel_type return_url}]
+    ad_returnredirect constraints-create?[export_vars {group_id rel_type return_url}]
 }
 
