@@ -7,10 +7,10 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Jan  2 12:23:02 2001
-    @cvs-id $Id: rel-type-remove.tcl,v 1.3 2002/09/06 21:49:59 jeffd Exp $
+    @cvs-id $Id: rel-type-remove.tcl,v 1.3.26.6 2014/07/29 11:23:56 gustafn Exp $
 
 } {
-    group_rel_id:integer,notnull
+    group_rel_id:naturalnum,notnull
     { return_url "" }
 } -properties {
     context:onevalue
@@ -30,9 +30,9 @@ if { ![db_0or1row select_info {
     return
 }
 
-ad_require_permission $group_id admin
+permission::require_permission -object_id $group_id -privilege admin
 
-set export_vars [ad_export_vars -form {group_rel_id return_url}]
-set context [list [list "[ad_conn package_url]admin/groups/" "Groups"] [list one?[ad_export_vars {group_id}] "One group"] "Remove relation type"]
+set export_vars [export_vars -form {group_rel_id return_url}]
+set context [list [list "[ad_conn package_url]admin/groups/" "Groups"] [list one?[export_vars {group_id}] "One group"] "Remove relation type"]
 
 ad_return_template
