@@ -1,10 +1,10 @@
 ad_page_contract {
     @author Mark Dettinger (mdettinger@arsdigita.com)
     @creation-date 2000-10-24
-    @cvs-id $Id: delete.tcl,v 1.3 2003/05/17 10:00:22 jeffd Exp $
+    @cvs-id $Id: delete.tcl,v 1.3.22.1 2014/08/05 09:49:24 gustafn Exp $
 } {
     host
-    node_id:integer
+    node_id:naturalnum,notnull
 }
 
 # Flush the cache
