@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Thu Jan  4 11:20:37 2001
-    @cvs-id $Id: constraints-redirect.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: constraints-redirect.tcl,v 1.2.10.4 2013/09/09 16:44:22 gustafn Exp $
 
 } {
     segment_id:naturalnum,notnull
@@ -16,11 +16,11 @@ ad_page_contract {
 
 set operation [string trim [string tolower $operation]]
 
-if { [string eq $operation "yes"] } {
-    ad_returnredirect "constraints/new?rel_segment=$segment_id&[ad_export_vars return_url]"
+if {$operation eq "yes"} {
+    ad_returnredirect "constraints/new?rel_segment=$segment_id&[export_vars return_url]"
 } else {
-    if { [empty_string_p $return_url] } {
-	set return_url "one?[ad_export_vars segment_id]"
+    if { $return_url eq "" } {
+	set return_url "one?[export_vars segment_id]"
     }
     ad_returnredirect $return_url
 }
