@@ -6,10 +6,10 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Dec 12 11:23:12 2000
-    @cvs-id $Id: delete-2.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: delete-2.tcl,v 1.2.10.5 2014/07/29 11:23:57 gustafn Exp $
 
 } {
-    segment_id:integer,notnull
+    segment_id:naturalnum,notnull
     { operation "" }
     { return_url "" }
 } -validate {
@@ -20,14 +20,14 @@ ad_page_contract {
     }
 }
 
-if { [string eq $operation "Yes, I really want to delete this segment"] } {
-    if { [empty_string_p $return_url] } {
+if {$operation eq "Yes, I really want to delete this segment"} {
+    if { $return_url eq "" } {
 	# Go back to the group for this segment
 	set group_id [db_string select_group_id {
 	    select s.group_id from rel_segments s where s.segment_id = :segment_id
 	} -default ""]
-	if { ![empty_string_p $group_id] } {
-	    set return_url "../groups/one?[ad_export_vars group_id]"
+	if { $group_id ne "" } {
+	    set return_url "../groups/one?[export_vars group_id]"
 	}
     }
 
@@ -37,8 +37,8 @@ if { [string eq $operation "Yes, I really want to delete this segment"] } {
     }
 } 
 
-if { [empty_string_p $return_url] } {
-    set return_url "one?[ad_export_vars {segment_id}]"
+if { $return_url eq "" } {
+    set return_url "one?[export_vars {segment_id}]"
 }
 
 ad_returnredirect $return_url
