@@ -4,10 +4,10 @@ ad_page_contract {
 
     @author lars@collaboraid.biz
     @creation-date 2003-06-11
-    @cvs-id $Id: edit.tcl,v 1.4 2004/03/04 14:52:48 jeffd Exp $
+    @cvs-id $Id: edit.tcl,v 1.5.18.1 2014/07/29 11:23:57 gustafn Exp $
 
 } {
-    segment_id:integer,notnull
+    segment_id:naturalnum,notnull
 } -validate {
     segment_exists_p -requires {segment_id:notnull} {
 	if { ![rel_segments_permission_p $segment_id] } {
@@ -42,6 +42,11 @@ ad_form -name segment -cancel_url $view_url -form {
         set    segment_name = :segment_name
         where  segment_id = :segment_id
     }
+    db_dml update_object_title {
+	update acs_objects
+	set title = :segment_name
+	where object_id = :segment_id
+    }
 } -after_submit {
     ad_returnredirect $view_url
     ad_script_abort
