@@ -7,11 +7,11 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Dec 12 10:45:07 2000
-    @cvs-id $Id: mapping-remove-2.tcl,v 1.4 2007/01/10 21:22:07 gustafn Exp $
+    @cvs-id $Id: mapping-remove-2.tcl,v 1.4.10.1 2014/08/05 09:49:24 gustafn Exp $
 
 } {
-    { group_rel_id:integer "" }
-    { group_type_rel_id "" }
+    { group_rel_id:naturalnum "" }
+    { group_type_rel_id:naturalnum "" }
     { return_url "" }
 } -properties {
     context:onevalue
