@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Wed Dec 13 10:20:29 2000
-    @cvs-id $Id: edit.tcl,v 1.3 2002/09/18 12:16:43 jeffd Exp $
+    @cvs-id $Id: edit.tcl,v 1.4.10.4 2013/09/09 16:44:23 gustafn Exp $
 
 } {
     role:notnull
@@ -22,7 +22,7 @@ db_1row select_role_props {
      where r.role = :role
 }
 
-set context [list [list "../" "Relationship types"] [list "one?[ad_export_vars role]" "One role"] "Edit"]
+set context [list [list "../" "Relationship types"] [list "one?[export_vars role]" "One role"] "Edit"]
 
 template::form create role_form
 
@@ -56,8 +56,8 @@ if { [template::form is_valid role_form] } {
 	       r.pretty_plural = :pretty_plural
 	 where r.role = :role
     } -bind [ns_getform]
-    if { [empty_string_p $return_url] } {
-	set return_url "one?[ad_export_vars role]"
+    if { $return_url eq "" } {
+	set return_url "one?[export_vars role]"
     }
     ad_returnredirect $return_url
     ad_script_abort
