@@ -6,10 +6,10 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Wed Dec 13 20:11:27 2000
-    @cvs-id $Id: change-member-state.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: change-member-state.tcl,v 1.2.10.1 2014/07/29 11:23:57 gustafn Exp $
 
 } {
-    rel_id:integer,notnull
+    rel_id:naturalnum,notnull
     member_state:notnull
     {return_url ""}
 } -validate {
@@ -32,7 +32,7 @@ db_dml update_member_state {
 }
 
 
-if {[empty_string_p $return_url]} {
+if {$return_url eq ""} {
     set return_url "one?rel_id=$rel_id"
 }
 ad_returnredirect $return_url
\ No newline at end of file
