@@ -4,11 +4,11 @@ ad_page_contract {
 
   @author rhs@mit.edu
   @creation-date 2000-09-12
-  @cvs-id $Id: mount.tcl,v 1.3 2003/05/17 10:01:14 jeffd Exp $
+  @cvs-id $Id: mount.tcl,v 1.3.22.2 2014/07/29 11:23:58 gustafn Exp $
 } {
-  node_id:integer,notnull
+  node_id:naturalnum,notnull
   {expand:integer,multiple {}}
-  root_id:integer,optional
+  root_id:naturalnum,optional
 }
 
 set user_id [ad_conn user_id]
