@@ -7,17 +7,17 @@ ad_page_contract {
 
     @author rhs@mit.edu
     @creation-date 2000-09-13
-    @cvs-id $Id: package-new.tcl,v 1.12 2007/01/10 21:22:08 gustafn Exp $
+    @cvs-id $Id: package-new.tcl,v 1.12.10.4 2014/08/05 09:49:25 gustafn Exp $
 
 } {
-    {new_package_id:integer ""}
-    node_id:integer,notnull
+    {new_package_id:naturalnum ""}
+    node_id:naturalnum,notnull
     {new_node_p f}
     {node_name:trim ""}
     {instance_name ""}
     package_key:notnull
     {expand:integer,multiple ""}
-    root_id:integer,optional
+    root_id:naturalnum,optional
 }
 
 if {$package_key eq "/new"} {
@@ -67,4 +67,4 @@ db_transaction {
     }
 }
 
-ad_returnredirect ".?[export_url_vars expand:multiple root_id]"
+ad_returnredirect ".?[export_vars -url {expand:multiple root_id}]"
