@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date 12 September 2000
-    @cvs-id $Id: parameter-set-2.tcl,v 1.4 2003/07/02 17:57:31 olah Exp $
+    @cvs-id $Id: parameter-set-2.tcl,v 1.5.8.1 2013/09/06 16:01:46 gustafn Exp $
 
 } {
     package_key:notnull
@@ -14,12 +14,12 @@ ad_page_contract {
     params:array
 }
 
-ad_require_permission $package_id admin
+permission::require_permission -object_id $package_id -privilege admin
 
 if { [catch {
     db_foreach apm_parameters_set {} {
 	if {[info exists params($parameter_id)]} {
-	    ad_parameter -set $params($parameter_id) -package_id $package_id $parameter_name $package_key 
+	    parameter::set_value -value $params($parameter_id) -package_id $package_id -parameter $parameter_name 
 	}
     }
 } errmsg] } {
