@@ -3,13 +3,13 @@ ad_page_contract {
     @author rhs@mit.edu
     @author bquinn@arsidigta.com
     @creation-date 2000-09-09
-    @cvs-id $Id: site-map.tcl,v 1.6 2008/07/29 22:04:14 emmar Exp $
+    @cvs-id $Id: site-map.tcl,v 1.6.8.8 2014/08/05 09:49:25 gustafn Exp $
     
 } {
     {expand:integer,multiple ""}
     {new_parent:integer ""}
     {new_type ""}
-    {root_id:integer ""}
+    {root_id:naturalnum ""}
     {new_application:integer ""}
     {rename_application:integer {}}
 }
@@ -29,7 +29,7 @@ set parent_id $node(parent_id)
 set object_id $node(object_id)
 
 if {$object_id ne ""} {
-    ad_require_permission $object_id admin
+    permission::require_permission -object_id $object_id -privilege admin
 }
 
 if {$new_parent ne ""} {
@@ -44,7 +44,7 @@ if {$new_parent ne ""} {
 set javascript "onload=\"javascript:document.check_checkbox()\""
 
 
-set parent_link ".?[export_url_vars expand:multiple root_id=$parent_id]"
+set parent_link ".?[export_vars -url {expand:multiple {root_id $parent_id}}]"
 
 set page_title "Build Your Site Map "
 set context [list [list "." "Site Map"] $page_title]
@@ -52,8 +52,8 @@ set context [list [list "." "Site Map"] $page_title]
 set user_id [ad_conn user_id]
 
 db_foreach path_select {} {
-    if {$node_id != $root_id && $admin_p eq "t"} {
-	append head "<a href=.?[export_url_vars expand:multiple root_id=$node_id]>"
+    if {$node_id != $root_id && $admin_p == "t"} {
+	append head "<a href=.?[export_vars -url {expand:multiple {root_id $node_id}}]>"
     }
     if {$name eq ""} {
 	append head "$obj_name:"
@@ -61,11 +61,11 @@ db_foreach path_select {} {
 	append head $name
     }
     
-    if {$node_id != $root_id && $admin_p eq "t"} {
+    if {$node_id != $root_id && $admin_p == "t"} {
 	append head "</a>"
     }
     
-    if {$directory_p eq "t"} {
+    if {$directory_p == "t"} {
 	append head "/"
     }
 } if_no_rows {
@@ -182,21 +182,21 @@ db_foreach nodes_select {} {
     set permissions_url ""
     if { [lsearch -exact $open_nodes $parent_id] == -1 && $parent_id ne "" && $mylevel > 2 } { continue } 
         
-    if {$directory_p eq "t"} {
-	set add_folder_url "?[export_url_vars expand:multiple root_id node_id new_parent=$node_id new_type=folder]"
+    if {$directory_p == "t"} {
+	set add_folder_url "?[export_vars -url {expand:multiple root_id node_id {new_parent $node_id} {new_type folder}}]"
 	if {$object_id eq ""} {
-	    set mount_url "mount?[export_url_vars expand:multiple root_id node_id]"
-	    set new_app_url "?[export_url_vars expand:multiple root_id new_application=$node_id]"
+	    set mount_url "mount?[export_vars -url {expand:multiple root_id node_id}]"
+	    set new_app_url "?[export_vars -url {expand:multiple root_id {new_application $node_id}}]"
 	} else {
 	    # This makes sure you can't unmount the thing that is serving the page you're looking at.
 	    if {[ad_conn node_id] != $node_id} {
-		set unmount_url "unmount?[export_url_vars expand:multiple root_id node_id]"
+		set unmount_url "unmount?[export_vars -url {expand:multiple root_id node_id}]"
 	    }
 	    
 	    # Add a link to control permissioning
 	    if {$object_admin_p} {
-		set permissions_url "../../permissions/one?[export_url_vars object_id]"
-		set rename_url "?[export_url_vars expand:multiple root_id rename_application=$node_id]"
+		set permissions_url "../../permissions/one?[export_vars -url {object_id}]"
+		set rename_url "?[export_vars -url {expand:multiple root_id {rename_application $node_id}}]"
 		set delete_url "instance-delete?package_id=$object_id&root_id=$root_id"
 	    }
 	    # Is the object a package?
@@ -209,7 +209,7 @@ db_foreach nodes_select {} {
     }
     
     if {[ad_conn node_id] != $node_id && $n_children == 0 && $object_id eq ""} {
-	set delete_url "delete?[export_url_vars expand:multiple root_id node_id]"
+	set delete_url "delete?[export_vars -url {expand:multiple root_id node_id}]"
     }
     
     # use the indent variable to hold current indent level we'll use it later to indent stuff at the end by the amount of the last node
@@ -247,7 +247,7 @@ db_foreach nodes_select {} {
 	set expand_url ""
     }
     
-    set name_url [export_url_vars expand:multiple root_id=$node_id]
+    set name_url [export_vars -url {expand:multiple {root_id $node_id}}]
         
     set action_type 0
     set action_form_part ""
@@ -256,7 +256,7 @@ db_foreach nodes_select {} {
 	if {$new_application == $node_id} {
 	    
 	    set action_type "new_app"
-	    set action_form_part "[export_form_vars expand:multiple root_id node_id new_package_id] [apm_application_new_checkbox]"
+	    set action_form_part "[export_vars -form {expand:multiple root_id node_id new_package_id}] [apm_application_new_checkbox]"
 	    
 	    #Generate a package_id for double click protection
 	    set new_package_id [db_nextval acs_object_id_seq]
@@ -265,7 +265,7 @@ db_foreach nodes_select {} {
 	}
     } elseif {$rename_application == $node_id} {
 	set action_type "rename_app"
-	set action_form_part "[export_form_vars expand:multiple root_id node_id rename_package_id]"
+	set action_form_part "[export_vars -form {expand:multiple root_id node_id rename_package_id}]"
 	
     } else {}
     
@@ -273,14 +273,14 @@ db_foreach nodes_select {} {
 	set parent_id $new_parent
 	set node_type $new_type	
 	set action_type "new_folder"
-	set action_form_part "[export_form_vars expand:multiple parent_id node_type root_id]"
+	set action_form_part "[export_vars -form {expand:multiple parent_id node_type root_id}]"
     }
 
     multirow append nodes $node_id $expand_mode $expand_url $indent $name $name_url $object_name $url $package_pretty_name $action_type $action_form_part $add_folder_url $new_app_url $unmount_url $mount_url $rename_url $delete_url $parameters_url $permissions_url "" $view_p
 
 }
 
-#set new_app_form_part_1 "<p align=\"top\"><form name=new_application action=package-new><input type=hidden name=node_id value=$node(node_id)><input type=hidden name=root_id value=$node(node_id) /><input type=hidden name=new_node_p value=t>[export_form_vars expand:multiple]<input name=node_name type=text size=8></p>"
+#set new_app_form_part_1 "<p align=\"top\"><form name=new_application action=package-new><input type=hidden name=node_id value=$node(node_id)><input type=hidden name=root_id value=$node(node_id) /><input type=hidden name=new_node_p value=t>[export_vars -form {expand:multiple}]<input name=node_name type=text size=8></p>"
 
 #set new_app_form_part_2 "<p align=\"top\">[apm_application_new_checkbox]</p>"
 #set new_app_form_part_3 "<p align=\"top\"><input type=submit value=\"Mount Package\"></form></p>"
