@@ -3,9 +3,9 @@ ad_page_contract {
     
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-08-07
-    @cvs-id $Id: group-leave.tcl,v 1.2.20.1 2013/08/27 12:20:37 gustafn Exp $
+    @cvs-id $Id: group-leave.tcl,v 1.2.20.2 2014/08/05 09:49:23 gustafn Exp $
 } {
-    {group_id:integer {[application_group::group_id_from_package_id]}}
+    {group_id:naturalnum,notnull {[application_group::group_id_from_package_id]}}
     return_url:optional
 }
 
