@@ -3,9 +3,9 @@ ad_page_contract {
     
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-06-02
-    @cvs-id $Id: member-remove.tcl,v 1.3 2004/01/26 15:39:46 jeffd Exp $
+    @cvs-id $Id: member-remove.tcl,v 1.3.20.1 2014/07/29 11:37:29 gustafn Exp $
 } {
-    user_id:integer,multiple
+    user_id:naturalnum,multiple
 }
 
 set group_id [application_group::group_id_from_package_id]
