@@ -1,11 +1,11 @@
 ad_page_contract {
     Change member state
 } {
-    {rel_id:multiple ""}
+    {rel_id:naturalnum,multiple ""}
     {member_state:notnull}
 }
 
-ad_require_permission $rel_id "admin"
+permission::require_permission -object_id $rel_id -privilege "admin"
 
 membership_rel::change_state \
     -rel_id $rel_id \
