@@ -1,6 +1,6 @@
 ad_page_contract {
     Interface for specifying a list of users to sign up as a batch
-    @cvs-id $Id: user-batch-add.tcl,v 1.4 2009/01/06 02:25:34 gustafn Exp $
+    @cvs-id $Id: user-batch-add.tcl,v 1.4.8.5 2013/09/09 16:44:25 gustafn Exp $
 } -properties {
     context:onevalue
     system_name:onevalue
@@ -19,7 +19,7 @@ first_names || ' ' || last_name from persons where person_id = :admin_user_id"]
 
 set context [list [list "./" "Users"] "Notify added user"]
 set system_name [ad_system_name]
-set export_vars [export_form_vars email first_names last_name user_id]
+set export_vars [export_vars -form {email first_names last_name user_id}]
 set system_url [parameter::get -package_id [ad_acs_kernel_id] -parameter SystemURL -default ""].
 
 ad_return_template
