@@ -7,16 +7,16 @@ ad_page_contract {
     
     @author rhs@mit.edu
     @creation-date 2000-08-29
-    @cvs-id $Id: index.tcl,v 1.2 2003/01/16 13:40:37 jeffd Exp $
+    @cvs-id $Id: index.tcl,v 1.3.16.1 2013/08/27 12:20:37 gustafn Exp $
 } { 
     root:trim,integer,optional
 }
 
-set user_id [ad_maybe_redirect_for_registration]
+set user_id [auth::require_login]
 
 set context "Permissions"
 
-if {![exists_and_not_null root]} { 
+if {(![info exists root] || $root eq "")} { 
     set root [ad_conn package_id]
 }
 
