@@ -6,15 +6,15 @@ ad_page_contract {
 
     @author rhs@mit.edu
     @creation-date 2000-08-20
-    @cvs-id $Id: one.tcl,v 1.13 2007/01/10 21:22:09 gustafn Exp $
+    @cvs-id $Id: one.tcl,v 1.13.10.3 2014/07/29 11:23:58 gustafn Exp $
 } {
-    object_id:integer,notnull
+    object_id:naturalnum,notnull
     {children_p "f"}
     {application_url ""}
 }
 
 set user_id [auth::require_login]
-ad_require_permission $object_id admin
+permission::require_permission -object_id $object_id -privilege admin
 
 # RBM: Check if this is the Main Site and prevent the user from being
 #      able to remove Read permission on "The Public" and locking
@@ -42,7 +42,7 @@ lappend controls "<a href=\"grant?[export_vars {application_url object_id}]\">[_
 
 db_1row context { *SQL* }
 
-if { $security_inherit_p eq "t" && $context_id ne "" } {
+if { $security_inherit_p == "t" && $context_id ne "" } {
     lappend controls "<a href=\"toggle-inherit?[export_vars {application_url object_id}]\">Don't Inherit Permissions from [ad_quotehtml $context_name]</a>"
 } else {
     lappend controls "<a href=\"toggle-inherit?[export_vars {application_url object_id}]\">Inherit Permissions from [ad_quotehtml $context_name]</a>"
@@ -55,7 +55,7 @@ set export_form_vars [export_vars -form {object_id application_url}]
 set show_children_url "one?[export_vars {object_id application_url {children_p t}}]"
 set hide_children_url "one?[export_vars {object_id application_url {children_p f}}]"
 
-if {$children_p eq "t"} {
+if {$children_p == "t"} {
     db_multirow children children { *SQL* } {
     }
 } else {
