@@ -4,9 +4,9 @@ ad_page_contract {
 
   @author rhs@mit.edu
   @creation-date 2000-08-20
-  @cvs-id $Id: revoke-2.tcl,v 1.4 2003/05/17 10:02:04 jeffd Exp $
+  @cvs-id $Id: revoke-2.tcl,v 1.5.10.1 2014/07/29 11:23:58 gustafn Exp $
 } {
-  object_id:integer,notnull
+  object_id:naturalnum,notnull
   revoke_list:multiple
   { operation "" }
   {application_url ""}
@@ -14,7 +14,7 @@ ad_page_contract {
 
 permission::require_permission -object_id $object_id -privilege admin
 
-if { [string eq $operation "Yes"] } {
+if {$operation eq "Yes"} {
     db_transaction {
 	foreach item $revoke_list {
 	    set party_id [lindex $item 0]
