@@ -3,19 +3,19 @@ ad_page_contract {
     Set on vacation to null.
 
     @author Multipe
-    @cvs-id $Id: set-on-vacation-to-null.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: set-on-vacation-to-null.tcl,v 1.2.10.1 2013/09/07 08:37:58 gustafn Exp $
 } -properties {
     site_link:onevalue
     home_link:onevalue
 }
 
-set user_id [ad_get_user_id]
+set user_id [ad_conn user_id]
 
 set no_alerts_until [db_string no_alerts_until {
     select no_alerts_until from users where user_id = :user_id
 } -default ""] 
 
-if { ![empty_string_p $no_alerts_until] } {
+if { $no_alerts_until ne "" } {
     set clear [db_null] 
     db_dml pvt_unset_no_alerts_until {
 	    update users 
