@@ -1,8 +1,8 @@
 ad_page_contract {
     Prompt the user for email and password.
-    @cvs-id $Id: index.tcl,v 1.13 2007/11/30 18:16:43 daveb Exp $
+    @cvs-id $Id: index.tcl,v 1.13.10.1 2014/08/05 09:49:26 gustafn Exp $
 } {
-    {authority_id ""}
+    {authority_id:naturalnum ""}
     {username ""}
     {email ""}
     {return_url ""}
