@@ -7,9 +7,9 @@ ad_page_contract {
     @author Randy O'Meara <omeara@got.net>
 
     @creation-date 2000-2-28
-    @cvs-id $Id: user-join.tcl,v 1.12.10.1 2013/08/27 12:20:38 gustafn Exp $
+    @cvs-id $Id: user-join.tcl,v 1.12.10.2 2014/08/05 09:49:26 gustafn Exp $
 } {
-    {group_id:integer {[application_group::group_id_from_package_id]}}
+    {group_id:naturalnum,notnull {[application_group::group_id_from_package_id]}}
     {rel_type:notnull "membership_rel"}
     {return_url {}}
 } -properties {
