@@ -5,7 +5,7 @@ ad_page_contract {
 
     @author Jon Salz <jsalz@mit.edu>
     @creation-date 28 Nov 1999
-    @cvs-id $Id: 1pixel.tcl,v 1.5 2013/03/30 19:07:24 gustafn Exp $
+    @cvs-id $Id: 1pixel.tcl,v 1.5.2.1 2014/04/01 18:37:31 gustafn Exp $
 } {
     r:integer
     g:integer
@@ -23,7 +23,7 @@ if { [catch {
     # insist on UTF8-encoding it). So we write to a file, then dump
     # the file's contents.
 
-    set file_name [ns_tmpnam]
+    set file_name [ad_tmpnam]
     ns_log "Notice" "logging to $file_name"
     set file [open $file_name w+]
     fconfigure $file -encoding binary -translation binary
