@@ -3,9 +3,9 @@ ad_page_contract {
 
     @author philg@mit.edu
     @creation-date 26 Sept 1999
-    @cvs-id $Id: portrait-thumbnail-bits.tcl,v 1.3 2007/01/10 21:22:10 gustafn Exp $
+    @cvs-id $Id: portrait-thumbnail-bits.tcl,v 1.3.10.1 2014/08/05 09:49:27 gustafn Exp $
 } {
-    user_id:integer
+    user_id:naturalnum,notnull
 }
 
 # NB: this really doesn't work! You can now pass a &size= parameter
