@@ -2,9 +2,9 @@ ad_page_contract {
     Let's the user change his/her password.  Asks
     for old password, new password, and confirmation.
     
-    @cvs-id $Id: password-update.tcl,v 1.22.8.1 2013/08/27 12:20:38 gustafn Exp $
+    @cvs-id $Id: password-update.tcl,v 1.22.8.2 2014/08/05 09:49:27 gustafn Exp $
 } {
-    {user_id {[ad_conn untrusted_user_id]}}
+    {user_id:naturalnum,notnull {[ad_conn untrusted_user_id]}}
     {return_url ""}
     {old_password ""}
     {message ""}
