@@ -5,7 +5,7 @@ ad_library {
 
     @creation-date 27 Feb 2000
     @author Jon Salz [jsalz@arsdigita.com]
-    @cvs-id $Id: aolserver-3-procs.tcl,v 1.6 2010/03/11 11:03:01 gustafn Exp $
+    @cvs-id $Id: aolserver-3-procs.tcl,v 1.6.6.1 2013/10/10 20:44:07 gustafn Exp $
 }
 
 # -1 = Not there or value was ""
@@ -16,7 +16,7 @@ proc ns_dbformvalue {formdata column type valuebyref} {
 
     upvar $valuebyref value
 
-    if {[ns_set get $formdata $column.NULL] eq "t"} {
+    if {[ns_set get $formdata $column.NULL] == "t"} {
 	set value ""
 	return 0
     }
