@@ -8,8 +8,8 @@ ad_library {
     every request.
 
     @author Jeff Davis <davis@xarg.net>
-    @creationd-date 2005-03-02
-    @cvs-id $Id: ds-stub-procs.tcl,v 1.3 2012/12/08 17:42:32 gustafn Exp $
+    @creation-date 2005-03-02
+    @cvs-id $Id: ds-stub-procs.tcl,v 1.3.2.1 2014/09/08 08:36:40 gustafn Exp $
 }
 
 if {[info commands ds_add] eq ""} {
