@@ -2,7 +2,7 @@ ad_library {
 
   @author rhs@mit.edu
   @creation-date 2000-09-09
-  @cvs-id $Id: exception-procs.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+  @cvs-id $Id: exception-procs.tcl,v 1.3.10.2 2013/10/02 22:55:55 gustafn Exp $
 }
 
 ad_proc -private ad_raise {exception {value ""}} {
@@ -25,13 +25,17 @@ ad_proc -private ad_try {code args} {
   any matching exception handlers.
 
   If you use this I will kill you.
+
+  @see with_finally 
+  @see with_catch
 } {
-  global errorInfo errorCode
 
   if {[set errno [catch {uplevel $code} result]]} {
-    if {$errno == 1 && [string equal [lindex $errorCode 0] "AD"] && \
-	[string equal [lindex $errorCode 1] "EXCEPTION"]} {
-      set exception [lindex $errorCode 2]
+    if {$errno == 1 
+	&& [lindex $::errorCode 0] eq "AD"
+	&& [lindex $::errorCode 1] eq "EXCEPTION"
+    } {
+      set exception [lindex $::errorCode 2]
 
       set matched 0
       for {set i 0} {$i < [llength $args]} {incr i 3} {
@@ -41,13 +45,13 @@ ad_proc -private ad_try {code args} {
 	}
       }
 
-      if $matched {
-	upvar [lindex $args [expr $i + 1]] var
+      if {$matched} {
+	upvar [lindex $args $i+1] var
 	set var $result
-	set errno [catch {uplevel [lindex $args [expr $i + 2]]} result]
+	set errno [catch {uplevel [lindex $args $i+2]} result]
       }
     }
 
-    return -code $errno -errorcode $errorCode -errorinfo $errorInfo $result
+    return -code $errno -errorcode $::errorCode -errorinfo $::errorInfo $result
   }
 }
