@@ -5,7 +5,7 @@ ad_library {
     @author Doug Harris (dharris@worldbank.org)
     @author Janine Sisk (jsisk@mit.edu)
     @creation-date 25 Feb 2002
-    @cvs-id $Id: html-email-procs.tcl,v 1.18 2010/01/13 10:55:33 emmar Exp $
+    @cvs-id $Id: html-email-procs.tcl,v 1.18.6.1 2013/08/28 23:02:48 michaels Exp $
 }
 
 # switched to using tcllib, its required for openacs >= 5.3
@@ -100,7 +100,10 @@ ad_proc parse_incoming_email {
     To make our lives simpler we support only text/html as a special case;
     in all other cases the plain text is returned.
 } {
-    set mime [mime::initialize -string $message]
+    if { [catch {set mime [mime::initialize -string $message]} err ] } {
+        ns_log error "parse_incoming_email: could not parse message; error was $err"
+        return ""
+    }
     set content [mime::getproperty $mime content]
 
     if { [string first "multipart" $content] != -1 } {
