@@ -5,16 +5,16 @@ ad_library {
     @creation-date 22 January 2003
 }
 
-aa_register_case -cats {smoke} server_error_log {
+aa_register_case -cats {smoke} -error_level warning server_error_log {
     Examine server error log.
-    } {
+} {
     # Log error lines start with something like this:
     # [19/Nov/2003:00:54:45][10491.319494][-conn1-] Error: 
     
     set logfile [ns_info log]
 
-    if { [string equal $logfile "STDOUT"] } {
-        set logfile "[acs_root_dir]/log/error/current"
+    if {$logfile eq "STDOUT"} {
+        set logfile "$::acs::rootdir/log/error/current"
     }
 
     set fd [open $logfile r]
@@ -28,7 +28,7 @@ aa_register_case -cats {smoke} server_error_log {
                 aa_log_result "fail" "$timestamp: $entry"
                 set inside_error_p 0
             }
-            if { [string equal $level "Error"] } {
+            if {$level eq "Error"} {
                 set inside_error_p 1
                 set entry {}
                 append entry $rest \n
@@ -38,5 +38,6 @@ aa_register_case -cats {smoke} server_error_log {
             append entry $line \n
         }
     }
+    close $fd
 }
 
