@@ -19,7 +19,7 @@ ad_library {
 # liability for all claims, expenses, losses, damages and costs any user may
 # incur as a result of using, copying or modifying this software.
 #
-    @cvs-id $Id: xml-1-dom-procs.tcl,v 1.2 2002/09/13 11:10:33 jeffd Exp $
+    @cvs-id $Id: xml-1-dom-procs.tcl,v 1.3.10.6 2013/10/12 13:55:19 gustafn Exp $
 }
 
 package provide dom 1.6
@@ -78,7 +78,7 @@ proc dom::GetHandle {type token varName} {
     array set data [set $token]
 
 # Type checking not implemented
-#    if {[string compare $data(node:nodeType) "document"]} {
+#    if {$data(node:nodeType) ne "document" } {
 #	return -code error "node is not of type document"
 #    }
 
@@ -142,7 +142,7 @@ proc dom::DOMImplementation {method args} {
 
 	    # Later on, could use Tcl package facility
 	    if {[regexp {create|destroy|parse|serialize|trim} [lindex $args 0]]} {
-		if {![string compare [lindex $args 1] "1.0"]} {
+		if {[lindex $args 1] eq "1.0" } {
 		    return 1
 		} else {
 		    return 0
@@ -394,7 +394,7 @@ proc dom::document {method token args} {
 	configure {
 	    if {[llength $args] == 1} {
 		return [document cget $token [lindex $args 0]]
-	    } elseif {[expr [llength $args] % 2]} {
+	    } elseif {[llength $args] % 2} {
 		return -code error "no value specified for option \"[lindex $args end]\""
 	    } else {
 		foreach {option value} $args {
@@ -485,7 +485,7 @@ proc dom::document {method token args} {
 		return -code error "wrong number of arguments"
 	    }
 
-	    foreach {name extid dtd entities notations} $args break
+	    lassign $args name extid dtd entities notations
 	    set result [CreateDocType $token $name $extid $dtd $entities $notations]
 	}
 
@@ -560,10 +560,11 @@ proc dom::CreateElement {token name aList args} {
 
     if {[string length $token]} {
 
-	if {![string compare $parent(node:nodeType) documentFragment]} {
+	if {$parent(node:nodeType) eq "documentFragment" } {
 	    if {$parent(id) == $parent(documentFragment:masterDoc)} {
-		if {[info exists parent(document:documentElement)] && \
-		    [string length $parent(document:documentElement)]} {
+		if {[info exists parent(document:documentElement)] 
+		    && [string length $parent(document:documentElement)]
+		} {
 		    unset docArray($id)
 		    return -code error "document element already exists"
 		} else {
@@ -571,7 +572,7 @@ proc dom::CreateElement {token name aList args} {
 		    # Check against document type decl
 		    if {[string length $parent(document:doctype)]} {
 			array set doctypedecl [set $parent(document:doctype)]
-			if {[string compare $name $doctypedecl(doctype:name)]} {
+			if {$name ne $doctypedecl(doctype:name) } {
 			    return -code error "mismatch between root element type in document type declaration \"$doctypedecl(doctype:name)\" and root element \"$name\""
 			}
 
@@ -845,7 +846,7 @@ proc dom::node {method token args} {
 			}
 		    }
 		    attributes {
-			if {[string compare $node(node:nodeType) element]} {
+			if {$node(node:nodeType) ne "element" } {
 			    set result {}
 			} else {
 			    set result $node(element:attributeList)
@@ -866,7 +867,7 @@ proc dom::node {method token args} {
 
 	    if {[llength $args] == 1} {
 		return [document cget $token [lindex $args 0]]
-	    } elseif {[expr [llength $args] % 2]} {
+	    } elseif {[llength $args] % 2} {
 		return -code error "no value specified for option \"[lindex $args end]\""
 	    } else {
 		foreach {option value} $args {
@@ -893,7 +894,7 @@ proc dom::node {method token args} {
 	    }
 
 	    GetHandle node [lindex $args 0] newChild
-	    if {[string compare $newChild(docArray) $node(docArray)]} {
+	    if {$newChild(docArray) ne $node(docArray) } {
 		return -code error "new node must be in the same document"
 	    }
 
@@ -909,7 +910,7 @@ proc dom::node {method token args} {
 		2 {
 
 		    GetHandle node [lindex $args 1] refChild
-		    if {[string compare $refChild(docArray) $newChild(docArray)]} {
+		    if {$refChild(docArray) ne $newChild(docArray) } {
 			return -code error "nodes must be in the same document"
 		    }
 		    set idx [lsearch [set $node(node:childNodes)] [lindex $args 1]]
@@ -1204,7 +1205,7 @@ proc dom::element {method token args} {
 	configure {
 	    if {[llength $args] == 1} {
 		return [document cget $token [lindex $args 0]]
-	    } elseif {[expr [llength $args] % 2]} {
+	    } elseif {[llength $args] % 2} {
 		return -code error "no value specified for option \"[lindex $args end]\""
 	    } else {
 		foreach {option value} $args {
@@ -1304,12 +1305,13 @@ proc dom::Element:GetByTagName {token name} {
 
     set result {}
 
-    if {[string compare $node(node:nodeType) "documentFragment"]} {
+    if {$node(node:nodeType) ne "documentFragment" } {
 	foreach child [set $node(node:childNodes)] {
 	    catch {unset childNode}
 	    array set childNode [set $child]
-	    if {![string compare $childNode(node:nodeType) element] && \
-		![string compare [GetField childNode(node:nodeName)] $name]} {
+	    if {$childNode(node:nodeType) eq "element" 
+		&& [GetField childNode(node:nodeName)] eq $name 
+	    } {
 		lappend result $child
 	    }
 	}
@@ -1317,7 +1319,7 @@ proc dom::Element:GetByTagName {token name} {
 	# Document Element must exist and must be an element type node
 	catch {unset childNode}
 	array set childNode [set $node(document:documentElement)]
-	if {![string compare $childNode(node:nodeName) $name]} {
+	if {$childNode(node:nodeName) eq $name } {
 	    set result $node(document:documentElement)
 	}
     }
@@ -1438,7 +1440,7 @@ proc dom::processinginstruction {method token args} {
 	configure {
 	    if {[llength $args] == 1} {
 		return [document cget $token [lindex $args 0]]
-	    } elseif {[expr [llength $args] % 2]} {
+	    } elseif {[llength $args] % 2} {
 		return -code error "no value specified for option \"[lindex $args end]\""
 	    } else {
 		foreach {option value} $args {
@@ -1491,10 +1493,10 @@ proc dom::processinginstruction {method token args} {
 proc dom::Serialize:documentFragment {token args} {
     array set node [set $token]
 
-    if {[string compare "node1" $node(documentFragment:masterDoc)]} {
+    if {"node1" ne $node(documentFragment:masterDoc) } {
 	return [eval [list Serialize:node $token] $args]
     } else {
-	if {[string compare {} [GetField node(document:documentElement)]]} {
+	if {{} ne [GetField node(document:documentElement)] } {
 	    return [eval Serialize:document [list $token] $args]
 	} else {
 	    return -code error "document has no document element"
@@ -1519,7 +1521,7 @@ proc dom::Serialize:document {token args} {
 
     if {![info exists node(document:documentElement)]} {
 	return -code error "document has no document element"
-    } elseif {![string length $node(document:doctype)]} {
+    } elseif {$node(document:doctype) eq ""} {
 	return -code error "no document type declaration given"
     } else {
 
@@ -1743,9 +1745,9 @@ proc dom::Serialize:attributeList {l} {
 	# Handle special characters
 	regsub -all < $value {\&lt;} value
 
-	if {![string match *\"* $value]} {
+	if {![string match "*\"*" $value]} {
 	    append result \"$value\"
-	} elseif {![string match *'* $value]} {
+	} elseif {![string match "*'*" $value]} {
 	    append result '$value'
 	} else {
 	    regsub -all \" $value {\&quot;} value
@@ -1926,7 +1928,7 @@ proc dom::Trim nodeid {
     switch $node(node:nodeType) {
 
 	textNode {
-	    if {![string length [string trim $node(node:nodeValue)]]} {
+	    if {[string trim $node(node:nodeValue)] eq ""} {
 		node removeChild $node(node:parentNode) $nodeid
 	    }
 	}
