@@ -5,14 +5,14 @@
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Authors: Christian Brechbuehler <christian@arsdigita.com
 
-# $Id: acs-integration-procs.tcl,v 1.20 2013/04/12 16:12:57 gustafn Exp $
+# $Id: acs-integration-procs.tcl,v 1.20.2.7 2014/07/07 18:53:40 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
 # http://www.fsf.org/copyleft/gpl.html
 
 ad_proc -public ad_return_template {
-     -string:boolean
+    -string:boolean
     {template ""}
 } {
     This function is a wrapper for sundry template:: procs. Will set the 
@@ -21,16 +21,16 @@ ad_proc -public ad_return_template {
     @param template Name of template file 
 
     @param string If specified, will return the resulting page to the caller
-                  string instead sending it to the connection.
+    string instead sending it to the connection.
 } {
     if {$template ne ""} {
-	template::set_file \
-	    [template::util::url_to_file $template [ad_conn file]]
+        template::set_file \
+            [template::util::url_to_file $template [ad_conn file]]
     }
     
     if { $string_p } {
-	return [template::adp_parse \
-		    [template::util::url_to_file $template [ad_conn file]] {}]
+        return [template::adp_parse \
+                    [template::util::url_to_file $template [ad_conn file]] {}]
     }
 }
 
@@ -53,12 +53,8 @@ ad_proc -public ad_parse_template {
     set template_params [list]
     foreach param $params {
         switch [llength $param] {
-            1 { lappend template_params "&"
-                lappend template_params [lindex $param 0]
-              }
-            2 { lappend template_params [lindex $param 0]
-                lappend template_params [lindex $param 1]
-              }
+            1 { lappend template_params "&" [lindex $param 0] }
+            2 { lappend template_params [lindex $param 0] [lindex $param 1] }
             default { return -code error [_ acs-templating.Template_parser_error_in_parameter_list] }
         }
     }
@@ -88,18 +84,18 @@ ad_proc -public ad_return_exception_template {
 ad_proc -public get_server_root {} {
     Get the server root directory (supposing we run under ACS)
 } {
-    file dir $::acs::tcllib
+    return $::acs::rootdir
 }
 
 
 ad_proc adp_parse_ad_conn_file {} {
     handle a request for an adp and/or tcl file in the template system.
 } {
-    namespace eval template variable parse_level ""
-    #ns_log debug "adp_parse_ad_conn_file => file '[file root [ad_conn file]]'"
+    set ::template::parse_level ""
+    #ns_log debug "adp_parse_ad_conn_file => file '[file rootname [ad_conn file]]'"
     template::reset_request_vars
 
-    set parsed_template [template::adp_parse [file root [ad_conn file]] {}]
+    set parsed_template [template::adp_parse [file rootname [ad_conn file]] {}]
 
     if {$parsed_template ne ""} {
         
@@ -108,6 +104,7 @@ ad_proc adp_parse_ad_conn_file {} {
         #
 
         if { [lang::util::translator_mode_p] } {
+            set apm_package_url [apm_package_url_from_key "acs-lang"]
             
             # Attempt to move all message keys outside of tags
             while { [regsub -all {(<[^>]*)(\x002\(\x001[^\x001]*\x001\)\x002)([^>]*>)} $parsed_template {\2\1\3} parsed_template] } {}
@@ -124,9 +121,9 @@ ad_proc adp_parse_ad_conn_file {} {
                 if { [string first "</select" [string tolower $select]] != -1 } {
                     set start [lindex $indices 1]
                 } else {
-                    set before [string range $parsed_template 0 [expr {[lindex $indices 0]-1}]]
+                    set before [string range $parsed_template 0 [lindex $indices 0]-1]
                     set message [string range $parsed_template [lindex $message_idx 0] [lindex $message_idx 1]]
-                    set after [string range $parsed_template [expr {[lindex $indices 1] + 1}] end]
+                    set after [string range $parsed_template [lindex $indices 1]+1 end]
                     set parsed_template "${before}${message}${select}${after}"
                 }
             }
@@ -134,16 +131,14 @@ ad_proc adp_parse_ad_conn_file {} {
             # TODO: We could also move message keys out of <head>...</head>
 
             while { [regexp -indices {\x002\(\x001([^\x001]*)\x001\)\x002} $parsed_template indices key] } {
-                set before [string range $parsed_template 0 [expr {[lindex $indices 0] - 1}]]
-                set after [string range $parsed_template [expr {[lindex $indices 1] + 1}] end]
+                set before [string range $parsed_template 0 [lindex $indices 0]-1]
+                set after [string range $parsed_template [lindex $indices 1]+1 end]
 
                 set key [string range $parsed_template [lindex $key 0] [lindex $key 1]]
+                lassign [split $key "."] package_key message_key
 
-                set keyv [split $key "."]
-                set package_key [lindex $keyv 0]
-                set message_key [lindex $keyv 1]
-
-                set edit_url [export_vars -base "[apm_package_url_from_key "acs-lang"]admin/edit-localized-message" { { locale {[ad_conn locale]} } package_key message_key { return_url [ad_return_url] } }]
+                set edit_url [export_vars -base "${apm_package_url}admin/edit-localized-message" { 
+                    { locale {[ad_conn locale]} } package_key message_key { return_url [ad_return_url] } }]
 
                 if { [lang::message::message_exists_p [ad_conn locale] $key] } {
                     set edit_link "<a href=\"$edit_url\" title=\"$key\" style=\"color: green;\"><b>o</b></a>"
@@ -153,7 +148,8 @@ ad_proc adp_parse_ad_conn_file {} {
                         set edit_link "<a href=\"$edit_url\" title=\"$key\" style=\"background-color: yellow; color: red;\"><b>*</b></a>"
                     } else {
                         # Message key missing entirely
-                        set new_url [export_vars -base "[apm_package_url_from_key "acs-lang"]admin/localized-message-new" { { locale en_US } package_key message_key { return_url [ad_return_url] } }]
+                        set new_url [export_vars -base "${apm_package_url}admin/localized-message-new" { 
+                            { locale en_US } package_key message_key { return_url [ad_return_url] } }]
                         set edit_link "<a href=\"$new_url\" title=\"$key\" style=\"background-color: red; color: white;\"><b>@</b></a>"
                     }
                 }
@@ -164,9 +160,16 @@ ad_proc adp_parse_ad_conn_file {} {
 
         set mime_type [template::get_mime_type]
         set header_preamble [template::get_mime_header_preamble $mime_type]
-	doc_return 200 $mime_type "$header_preamble$parsed_template"
+        doc_return 200 $mime_type "$header_preamble$parsed_template"
     } else {
         db_release_unused_handles
     }
 }
 
+#
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
+
