@@ -3,7 +3,7 @@
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Authors: Simon Huynh (shuynh@arsdigita.com)
 
-# $Id: doc-tcl-procs.tcl,v 1.9 2003/11/01 08:45:37 jeffd Exp $
+# $Id: doc-tcl-procs.tcl,v 1.10.10.3 2014/09/10 18:17:20 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -42,11 +42,10 @@ ad_proc -private doc::sort_@see { list_ref directive_comments } {
     procedure to deal with @see comments
 } {
   upvar $list_ref see_list
-  set type [lindex $directive_comments 0]
-  set see_name [lindex $directive_comments 1]
-  set url [lindex $directive_comments 2]
 
-  if {$url ==  "" } {
+  lassign $directive_comments type see_name url
+
+  if {$url eq "" } {
     switch -exact $type {
 
 	namespace {
@@ -57,7 +56,7 @@ ad_proc -private doc::sort_@see { list_ref directive_comments } {
 	  set split_name $see_name
 	  doc::util::text_divider split_name ::
 	  set name_length [llength $split_name]
-	  set see_namespace [join [lrange $split_name 0 [expr $name_length - 2]] ""]
+	  set see_namespace [join [lrange $split_name 0 $name_length-2] ""]
 	  set url "[doc::util::dbl_colon_fix $see_namespace].html#[set see_name]"
 	}
     }
@@ -91,9 +90,9 @@ ad_proc -private doc::util::find_marker_indices { text marker } {
   set last_index -1
    
   while { [regexp -indices $marker $text marker_idx] } {
-    lappend indices_list [expr [lindex $marker_idx 0] + $last_index]
-    set text [string range $text [expr [lindex $marker_idx 1] + 1]  end]
-    set last_index [expr [lindex $marker_idx 1] + $last_index + 1]
+    lappend indices_list [expr {[lindex $marker_idx 0] + $last_index}]
+    set text [string range $text [lindex $marker_idx 1]+1 end]
+    set last_index [expr {[lindex $marker_idx 1] + $last_index + 1}]
   }
 
   # check for cases with no markers
@@ -119,7 +118,7 @@ ad_proc -private doc::util::text_divider { text_ref marker } {
     set result_list [list]
 
     # first check for no markers present
-    if { $indices_list == "end" } {
+    if { $indices_list eq "end" } {
 	set text [list $text]
 	return 0
     }
@@ -128,7 +127,7 @@ ad_proc -private doc::util::text_divider { text_ref marker } {
 
     foreach index $indices_list {
 	lappend result_list [string range $text $old_index $index]
-	set old_index [expr $index + 1]
+	set old_index [expr {$index + 1}]
     }
     
     lappend result_list [string range $text $old_index end]
@@ -137,10 +136,12 @@ ad_proc -private doc::util::text_divider { text_ref marker } {
     return 1
 }
 
-ad_proc -private template::util::server_root {} {
+ad_proc -private -deprecated template::util::server_root {} {
     uses ns_library to find the server root, may not always be accurate
     because it essentially asks for the tcl library path and
-    strips off the last /tcl directory
+    strips off the last /tcl directory.
+
+    @see use $::acs::rootdir instead
 } {
 
   set path_length [expr [llength [file split [ns_library private]]] - 1]
@@ -168,8 +169,10 @@ ad_proc -private template::util::write_from_template { template file_name} {
 
 }
 
-ad_proc -private template::util::display_value { ref } {
+ad_proc -private -deprecated template::util::display_value { ref } {
     a proc used for debugging, just prints out a value to the error log
+
+    @see use simple "ns_log ...." instead
 } {
     upvar $ref value
     ns_log notice "$ref: $value
@@ -177,15 +180,18 @@ ad_proc -private template::util::display_value { ref } {
 }
 
 
-ad_proc -private template::util::proper_noun { string_ref } {
+ad_proc -private -deprecated template::util::proper_noun { string_ref } {
     capitalizes the first letter of a string
     @return returns formatted string (UNFINISHED. FIXME.)
+    @see use "string totitle ..."
 } {
 
 }
 
 
-ad_proc -private template::util::string_range { string indices } {
+ad_proc -private -deprecated template::util::string_range { string indices } {
+    @see use "string range instead"
+} {
     return [string range $string [lindex $indices 0] [lindex $indices 1]]
 }
 
@@ -273,9 +279,7 @@ ad_proc -private template::util::alphabetized_index {list entry} {
 ad_proc -private template::util::proc_element_compare { element1 element2 } {
     used to compare two different elements in a list of parsed data for public or private procs
 } {
-
-    return [string compare -nocase [lindex [lindex [lindex $element2 1] 0] 1] [lindex [lindex [lindex $element1 1] 0] 1]]
-
+    return [string compare -nocase [lindex $element2 1 0 1] [lindex $element1 1 0 1]]
 }
 
 ad_proc -private doc::set_proc_name_source_text_comment_text { proc_block } {
@@ -355,7 +359,7 @@ ad_proc -private doc::parse_comment_text { proc_block } {
 			default "[lrange [lindex $directive_comments 1] 1 end]" \
 			description "[lrange $directive_comments 2 end]" ]
 		} else {
-		    if {$directive_type == "param"} {
+		    if {$directive_type eq "param"} {
 			set default_comment "required"
 		    } else {
 			set default_comment ""
@@ -430,7 +434,7 @@ ad_proc -private doc::parse_namespace { text_lines }  {
 
                 set namespace_name [lindex $directive_comments 0]
                 set namespace_description [lrange $directive_comments 1 end]
-                if {$namespace_description != "" } {
+                if {$namespace_description ne "" } {
 		    set has_comments 1
 		}
             }
@@ -468,9 +472,9 @@ ad_proc -private doc::parse_namespace { text_lines }  {
 
         set namespace_entry [lindex $total_result_listing [lsearch -exact $namespace_list $namespace_name]]
 
-	set namespace_info [lindex [lindex $namespace_entry 0] 1]
-	set namespace_public [lindex [lindex $namespace_entry 1] 1]
-	set namespace_private [lindex [lindex $namespace_entry 2] 1]
+	set namespace_info [lindex $namespace_entry 0 1]
+	set namespace_public [lindex $namespace_entry 1 1]
+	set namespace_private [lindex $namespace_entry 2 1]
 		
     } else {
         set namespace_info [list name "$namespace_name" overview "$namespace_description" author "$namespace_author" see "$namespace_see"]
@@ -603,7 +607,7 @@ ad_proc -private doc::parse_tcl_library { dir_list } {
   foreach dir $dir_list {
 
   #debug
-  template::util::display_value dir
+  #template::util::display_value dir
 
   # using this lame hack since most aD servers are running an earlier version of Tcl than 8.3,
   # which supports the -directory switch that this hack emulates
@@ -612,7 +616,7 @@ ad_proc -private doc::parse_tcl_library { dir_list } {
   }
 
   #debugging
-  template::util::display_value file_list
+  #template::util::display_value file_list
 
   foreach tcl_file $file_list {
       ns_log notice "doc::parse_tcl_library: parsing through $tcl_file for documentation"
