@@ -4,7 +4,7 @@ ad_page_contract {
 
   @author rhs@mit.edu
   @creation-date 2000-10-23
-  @cvs-id $Id: index.tcl,v 1.1 2006/02/09 06:39:55 jiml Exp $
+  @cvs-id $Id: index.tcl,v 1.1.12.1 2013/09/06 12:06:51 gustafn Exp $
 } -query {
   orderby:optional
 } -properties {
@@ -17,7 +17,7 @@ set package_id [ad_conn package_id]
 set user_id [ad_conn user_id]
 
 set context [list]
-set create_p [ad_permission_p $package_id create]
+set create_p [permission::permission_p -object_id $package_id -privilege create]
 
 # New here, is the use of -key to signify which column is the key field,
 # and the -bulk_actions to give us the ability to delete all the checked
