@@ -4,13 +4,13 @@ ad_page_contract {
 
   @author rhs@mit.edu
   @creation-date 2000-10-23
-  @cvs-id $Id: delete.tcl,v 1.2 2006/02/10 08:16:59 jiml Exp $
+  @cvs-id $Id: delete.tcl,v 1.2.12.2 2014/07/29 11:23:59 gustafn Exp $
 } {
-  template_demo_note_id:integer,notnull,multiple
+  template_demo_note_id:naturalnum,notnull,multiple
 }
 
 foreach template_demo_note_id $template_demo_note_id {
-    ad_require_permission $template_demo_note_id delete
+    permission::require_permission -object_id $template_demo_note_id -privilege delete
 
     package_exec_plsql -var_list [list [list template_demo_note_id $template_demo_note_id]] template_demo_note del
 }
