@@ -1,5 +1,5 @@
 ad_page_contract {
-  @cvs-id $Id: sandwich.tcl,v 1.2 2002/09/10 22:22:16 jeffd Exp $
+  @cvs-id $Id: sandwich.tcl,v 1.3.10.1 2013/10/10 21:20:11 gustafn Exp $
 } {
   {grid ""}
 } -properties {}
@@ -31,6 +31,6 @@ if { [form is_request sandwich] } {
 }
 
 # Choose standard or gridded output
-if { [string equal [element get_value sandwich grid] t] } {
+if {[element get_value sandwich grid] == "t"} {
   ad_return_template sandwich-grid
 }
