@@ -24,7 +24,7 @@
     --   be a part of the WebKit.prototype, we won't trample on namespace
     --   that way.
     --
-    --  $HeadURL: http://svn.xinha.org/trunk/modules/WebKit/WebKit.js $
+    --  $HeadURL: http://svn.xinha.webfactional.com/trunk/modules/WebKit/WebKit.js $
     --  $LastChangedDate: 2008-12-31 08:18:54 +1300 (Wed, 31 Dec 2008) $
     --  $LastChangedRevision: 1146 $
     --  $LastChangedBy: nicholasbs $
@@ -35,7 +35,7 @@ WebKit._pluginInfo = {
   origin        : "Xinha Core",
   version       : "$LastChangedRevision: 1146 $".replace(/^[^:]*:\s*(.*)\s*\$$/, '$1'),
   developer     : "The Xinha Core Developer Team",
-  developer_url : "$HeadURL: http://svn.xinha.org/trunk/modules/WebKit/WebKit.js $".replace(/^[^:]*:\s*(.*)\s*\$$/, '$1'),
+  developer_url : "$HeadURL: http://svn.xinha.webfactional.com/trunk/modules/WebKit/WebKit.js $".replace(/^[^:]*:\s*(.*)\s*\$$/, '$1'),
   sponsor       : "",
   sponsor_url   : "",
   license       : "htmlArea"
