@@ -2,10 +2,10 @@ ad_page_contract {
   @author Guenter Ernst guenter.ernst@wu-wien.ac.at, 
   @author Gustaf Neumann neumann@wu-wien.ac.at
   @creation-date 13.07.2004
-  @cvs-id $Id: insert-ilink.tcl,v 1.2 2006/06/04 00:45:54 donb Exp $
+  @cvs-id $Id: insert-ilink.tcl,v 1.2.12.2 2014/07/29 11:14:16 gustafn Exp $
 } {
-  {fs_package_id:integer,optional}
-  {folder_id:integer,optional}
+  {fs_package_id:naturalnum,optional}
+  {folder_id:naturalnum,optional}
   {file_types *}
 }
  
@@ -14,8 +14,4 @@ set file_selector_link [export_vars -base file-selector \
 			    {fs_package_id folder_id selector_type file_types}]
 set fs_found 1
 
-#set user_id [ad_verify_and_get_user_id]
-#permission::require_permission -party_id $user_id -object_id $fs_package_id \
-#    -privilege "admin"
-
 ad_return_template
