@@ -2,10 +2,10 @@ ad_page_contract {
   @author Guenter Ernst guenter.ernst@wu-wien.ac.at, 
   @author Gustaf Neumann neumann@wu-wien.ac.at
   @creation-date 13.07.2004
-  @cvs-id $Id: insert-image.tcl,v 1.2 2006/06/04 00:45:54 donb Exp $
+  @cvs-id $Id: insert-image.tcl,v 1.2.12.1 2014/07/29 11:14:16 gustafn Exp $
 } {
-  {fs_package_id:integer,optional}
-  {folder_id:integer,optional}
+  {fs_package_id:naturalnum,optional}
+  {folder_id:naturalnum,optional}
 }
  
 set selector_type "image"
