@@ -3,10 +3,10 @@ ad_page_contract {
 
     @author Tracy Adams (teadams@alum.mit.edu)
     @creation-date 22 July 2002
-    @cvs-id $Id: object-goto.tcl,v 1.2.22.1 2013/08/26 07:57:13 gustafn Exp $
+    @cvs-id $Id: object-goto.tcl,v 1.2.22.2 2014/08/06 11:07:26 gustafn Exp $
 } {
-    object_id:notnull
-    type_id:notnull
+    object_id:naturalnum,notnull
+    type_id:naturalnum,notnull
 } 
 
 
