@@ -4,9 +4,9 @@ ad_page_contract {
 
     @author Tracy Adams (teadams@alum.mit.edu))
     @creation-date 2002-09-03
-    @cvs-id $Id: request-change-frequency.tcl,v 1.3 2009/09/13 23:54:42 donb Exp $
+    @cvs-id $Id: request-change-frequency.tcl,v 1.3.6.1 2014/07/29 11:24:09 gustafn Exp $
 } {
-    request_id:integer,notnull
+    request_id:naturalnum,notnull
     return_url
 }
 
