@@ -6,9 +6,9 @@ ad_page_contract {
     @create-date 2005-03-28
 
 } {
-  object_id:integer,notnull
-  type_id
-  {group_id ""}
+  object_id:naturalnum,notnull
+  type_id:naturalnum,notnull
+  {group_id:naturalnum ""}
 }
 
 set package_id [ad_conn package_id]
@@ -61,7 +61,7 @@ element create notify delivery_method_id\
     -widget select\
     -label  "[_ notifications.Delivery_Method]"\
     -options $delivery_methods\
-    -value [lindex [lindex $delivery_methods 0] 1]
+    -value [lindex $delivery_methods 0 1]
 
 
 set username ""        
