@@ -1,7 +1,7 @@
 -- Drop the ACS Reference Country data
 --
 -- @author jon@jongriffin.com
--- @cvs-id $Id: ref-countries-drop.sql,v 1.1 2001/09/15 00:49:28 donb Exp $
+-- @cvs-id $Id: ref-countries-drop.sql,v 1.1.22.1 2014/09/05 16:52:43 gustafn Exp $
 
 -- drop all associated tables and packages
 -- I am not sure this is a good idea since we have no way to register
@@ -10,16 +10,24 @@
 -- This will probably fail if their is a child table using this.
 -- I can probably make this cleaner also, but ... no time today
 
-create function inline_0() returns integer as '
-declare
+
+
+--
+-- procedure inline_0/0
+--
+CREATE OR REPLACE FUNCTION inline_0(
+
+) RETURNS integer AS $$
+DECLARE
     rec        acs_reference_repositories%ROWTYPE;
-begin
-    for rec in select * from acs_reference_repositories where upper(table_name) like ''COUNTR%'' loop
-	 execute ''drop table '' || rec.table_name;
+BEGIN
+    for rec in select * from acs_reference_repositories where upper(table_name) like 'COUNTR%' loop
+	 execute 'drop table ' || rec.table_name;
          perform acs_reference__delete(rec.repository_id);
     end loop;
     return 0;
-end;' language 'plpgsql';
+END;
+$$ LANGUAGE plpgsql;
 
 select inline_0();
 drop function inline_0();
