@@ -1,7 +1,7 @@
 -- Drop the ACS Reference Country data
 --
 -- @author jon@jongriffin.com
--- @cvs-id $Id: ref-language-drop.sql,v 1.4 2010/05/14 12:22:49 emmar Exp $
+-- @cvs-id $Id: ref-language-drop.sql,v 1.4.6.1 2014/09/05 16:55:07 gustafn Exp $
 
 -- drop all associated tables and packages
 -- I am not sure this is a good idea since we have no way to register
@@ -12,16 +12,21 @@
 
 drop table language_639_2_codes;
 
-create function inline_0() returns integer as '
-declare
+--
+-- procedure inline_0/0
+--
+CREATE OR REPLACE FUNCTION inline_0(
+) RETURNS integer AS $$
+DECLARE
     rec        acs_reference_repositories%ROWTYPE;
-begin
-    for rec in select * from acs_reference_repositories where upper(table_name) = ''LANGUAGE_CODES'' loop
-	 execute ''drop table '' || rec.table_name;
+BEGIN
+    for rec in select * from acs_reference_repositories where upper(table_name) = 'LANGUAGE_CODES' loop
+	 execute 'drop table ' || rec.table_name;
          perform acs_reference__delete(rec.repository_id);
     end loop;
     return 0;
-end;' language 'plpgsql';
+END;
+$$ LANGUAGE plpgsql;
 
 select inline_0();
 drop function inline_0();
